﻿Imports System.Runtime.ConstrainedExecution
Imports XCM
Imports XSP
''' ---------------------------------------------
''' <summary>
''' 診療情報管理 共通帳票 科歴Report継承元クラス
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public Class MRP050R000

#Region "解放処理"
	'確実な解放処理を実行するために指定
	Inherits CriticalFinalizerObject
	'解放処理を実装する為に指定
	Implements IDisposable

	''' ---------------------------------------------
	''' <summary>
	''' Dispose（解放処理）※外からはよばない
	''' </summary>
	''' <param name="disposing"></param>
	''' <remarks>
	''' 2010/11/22 新規作成　ACS)常包<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overridable Overloads Sub Dispose(ByVal disposing As Boolean)
		If disposing Then
			Me.pForm = Nothing
			Me.pPrint = Nothing
			Me.pDgv = Nothing
			Me.pTitle = Nothing
			Me.pPrivacy = Nothing
			Me.pMakeWork = Nothing
		End If
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' Finalize（解放処理）
	''' </summary>
	''' <remarks>
	''' 2010/11/22 新規作成　ACS)常包<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overloads Sub Dispose() Implements IDisposable.Dispose
		Dispose(True)
		MyBase.Finalize()
		GC.SuppressFinalize(Me)
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' Finalize（解放処理）※外からはよばない
	''' </summary>
	''' <remarks>
	''' 2010/11/22 新規作成　ACS)常包<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overrides Sub Finalize()
		Dispose(False)
		MyBase.Finalize()
	End Sub
#End Region

#Region "コンスタント"

	Protected Enum ENUM_SQLTYPE As Byte
		''' <summary>
		''' ワーク作成
		''' </summary>
		INS = 0
		''' <summary>
		''' ワーク更新
		''' </summary>
		UPD = 1
		''' <summary>
		''' ワーク更新(カルテ管理状況(患者単位))
		''' </summary>
		UPD_REC_Pat = 2
		''' <summary>
		''' ワーク更新(カルテ管理状況(入退院単位))
		''' </summary>
		UPD_REC_Hsp = 3
		''' <summary>
		''' ワーク更新(カルテ管理状況(科歴単位))
		''' </summary>
		UPD_REC_Ch = 4
		''' <summary>
		''' ワーク更新(サマリ管理状況(科歴単位))
		''' </summary>
		UPD_SUM = 5
		''' <summary>
		''' ワーク更新(転科元コード)
		''' </summary>
		UPD_FROM = 6
		''' <summary>
		''' ワーク更新(転科先コード)
		''' </summary>
		UPD_TO = 7
	End Enum

	Protected Const CST_LOG_CLASS As String = "科歴一覧（Report）"
#End Region

#Region "変数"
	Private pForm As frmBase = Nothing						'遷移元画面
	Private pPrint As Boolean = Nothing						'印刷フラグ
	Protected pDgv As DataGridView = Nothing				'出力元グリッド
	Private pTitle As String = Nothing						'タイトル情報
	Protected pPrivacy As Boolean = Nothing					'個人情報出力フラグ
	Protected pMakeWork As Boolean = Nothing				'ワークデータ作成フラグ
	Protected pPatientNo As String = Nothing				'患者番号
	Protected pHspNo As Integer = Nothing					'入退院歴番号
	Protected pChNo As Integer = Nothing					'科歴番号
#End Region

#Region "コンストラクタ"

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ(検索サブシステムより呼び出し時)
	''' </summary>
	''' <param name="pForm">呼出画面</param>
	''' <param name="pPrint">印刷フラグ True:印刷/False:プレビュー</param>
	''' <param name="pDgv">一覧</param>
	''' <param name="pTitle">帳票タイトル</param>
	''' <param name="pPrivacy">個人情報出力フラグ True:出力する/False:出力しない</param>
	''' <param name="pMakeWork">ワークデータ作成フラグ True:作成する/False:作成しない</param>
	''' <remarks>
	''' </remarks>
	''' ---------------------------------------------
	Sub New(ByVal pForm As frmBase, ByVal pPrint As Boolean,
			ByVal pDgv As DataGridView, ByVal pTitle As String,
			ByVal pPrivacy As Boolean, ByVal pMakeWork As Boolean)
		'IN項目引き継ぎ
		Me.pForm = pForm
		Me.pPrint = pPrint
		Me.pDgv = pDgv
		Me.pTitle = pTitle
		Me.pPrivacy = pPrivacy
		Me.pMakeWork = pMakeWork
		Me.pPatientNo = Nothing
		Me.pHspNo = Nothing
		Me.pChNo = Nothing
	End Sub

	 ''' ---------------------------------------------
	 ''' <summary>
	 ''' コンストラクタ(登録サブシステムより呼び出し時)
	 ''' </summary>
	 ''' <param name="pForm">呼出画面</param>
	 ''' <param name="pPrint">印刷フラグ True:印刷/False:プレビュー</param>
	 ''' <param name="pTitle">帳票タイトル</param>
	 ''' <param name="pPrivacy">個人情報出力フラグ True:出力する/False:出力しない</param>
	 ''' <param name="pPatientNo">患者番号</param>
	 ''' <param name="pHspNo">入退院歴番号</param>
	 ''' <param name="pChNo">科歴番号</param>
	 ''' <remarks>
	 ''' </remarks>
	 ''' ---------------------------------------------
	Sub New(ByVal pForm As frmBase, ByVal pPrint As Boolean,
			ByVal pTitle As String, ByVal pPrivacy As Boolean,
			ByVal pPatientNo As String,
			Optional ByVal pHspNo As Integer = Nothing,
			Optional ByVal pChNo As Integer = Nothing)
		'IN項目引き継ぎ
		Me.pForm = pForm
		Me.pPrint = pPrint
		Me.pDgv = Nothing
		Me.pTitle = pTitle
		Me.pPrivacy = pPrivacy
		Me.pMakeWork = True
		Me.pPatientNo = pPatientNo
		Me.pHspNo = pHspNo
		Me.pChNo = pChNo
	End Sub

#End Region

#Region "メソッド"

	''' ---------------------------------------------
	''' <summary>
	''' 印刷・プレビュー処理
	''' </summary>	
	''' <remarks>
	''' 2010/11/22 新規作成　ACS)常包<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overridable Function exeReport() As Boolean
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, "exeReport", clsMRPCOMMON.CST_LOG_PRODUCT, CST_LOG_CLASS, "印刷・プレビュー処理")
		Dim cliAccess As clsXTM_PRINTSETTING_ACCESS
		Dim datAccess As datXTM_PRINTSETTING_ACCESS_OneRec = Nothing
		Dim cliCom As clsCom
		Dim FilePath As String = Nothing
		Try
			'印刷設定情報取得
			cliAccess = New clsXTM_PRINTSETTING_ACCESS
			datAccess = cliAccess.getAccessSettingOneRec(Me.pForm.Name, Me.GetType.Name)
			If datAccess Is Nothing Then
				Return False
			End If
			'MDBのパスを取得
			cliCom = New clsCom
			FilePath = cliCom.setReportPath(datAccess.FILE_NM)
			Using cliReportFunc As New clsReportFunc(Me.pForm, FilePath, datAccess.REPORT_NM, Me.pPrint)
				'DB処理
				Using db As New clsDB(clsSysMst.ctlConfigData)
					'ワークテーブルのクリア
					cliReportFunc.exeHeaderDel(db, Me.GetType.Name, True)
					For Each Sql As String In Me.getDelSql
						cliReportFunc.exeWorkDel(db, Sql, sqlMRPCOMMON.prmHOST_NM)
					Next
					'ヘッダの作成
					cliReportFunc.exeHeaderIns(db, Me.getHeaderData, True)
					'印刷データの作成
					Me.setWorkData(db)
				End Using
				'印刷/プレビュー
				If cliReportFunc.AcPrint(datAccess.NUMBERPRINTED) = False Then
					Return False
				End If
			End Using
			Return True
		Catch ex As Exception
			Throw
		Finally
			cliAccess = Nothing
			datAccess = Nothing
			cliCom = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' ワーク削除SQL取得
	''' </summary>
	''' <returns>SQL文</returns>
	''' <remarks>
	''' 2010/11/22 新規作成　ACS)常包<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overridable Function getDelSql() As String()
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, "getDelSql", clsMRPCOMMON.CST_LOG_PRODUCT, CST_LOG_CLASS, "ワーク削除SQL取得 START")
		Try
			If Me.pMakeWork = True Then
				Return New String() {sqlMRP050R000.sqlDel}
			Else
				Return New String() {}
			End If
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' ヘッダ情報編集
	''' </summary>
	''' <returns>ヘッダ情報</returns>
	''' <remarks>
	''' 2010/11/22 新規作成　ACS)常包<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overridable Function getHeaderData() As datHeader
		clsSysMst.logEx(XCM.clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, "getHeaderData", clsMRPCOMMON.CST_LOG_PRODUCT, CST_LOG_CLASS, "ヘッダ情報編集")
		Dim retHeader As datHeader
		Try
			retHeader = New datHeader
			With retHeader
				.PRT_ID = Me.GetType.Name										'帳票ID	
				.TITLE_NM = Me.pTitle											'タイトル
				.STR1 = Math.Abs(CInt(Me.pPrivacy)).ToString					'個人情報
				.STR2 = clsSysMst.ctlEnvData.getEnv(datEnv.Enum_ENV.ENV_00001)	'病歴番号
				.STR3 = clsSysMst.ctlEnvData.getEnv(datEnv.Enum_ENV.ENV_00003)	'生年月日書式
				.STR4 = clsSysMst.ctlEnvData.getEnv(datEnv.Enum_ENV.ENV_00050)	'表示年齢の基準日
			End With
			Return retHeader
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' ワークデータ作成
	''' </summary>
	''' <param name="db">clsDB</param>
	''' <returns>True:正常終了/False:異常終了</returns>
	''' <remarks>
	''' 2010/11/22 新規作成　ACS)常包<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overridable Function setWorkData(ByVal db As clsDB) As Boolean
		clsSysMst.logEx(XCM.clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, "setWorkData", clsMRPCOMMON.CST_LOG_PRODUCT, CST_LOG_CLASS, "ワークデータ作成")
		Dim row As DataRow
		Dim no As Integer
		Try
			'ワークデータは前回内容を再利用のため、更新しない
			If Me.pMakeWork = False Then Return True
			With db
				'ワークを追加・トランで更新
				For Each SqlType As Byte In [Enum].GetValues(GetType(ENUM_SQLTYPE))
					Select Case SqlType
						Case ENUM_SQLTYPE.INS	 'ワーク追加
							Me.setSql(db, ENUM_SQLTYPE.INS)
							If Me.pDgv IsNot Nothing Then
								'一覧からワークへ
								For Each pRow As DataGridViewRow In Me.pDgv.Rows			'明細ワーク
									'１行ずつデータを追加する
									row = CType(pRow.DataBoundItem, DataRowView).Row		'データを明細化
									'データグリッドにチェックがあるもののみ出力
									If row.Item(sqlMRPCOMMON.itmSELECTED) = CStr(clsConst.Enum_Chk.ChkOn) Then
										With db
											no += 1											'表示順 カウンタUP
											.setVal(sqlMRPCOMMON.prmDSPORDER, no)
											.setVal(sqlMRPCOMMON.prmPATIENT_NO, row.Item(sqlMRPCOMMON.itmPATIENT_NO).ToString)	'患者番号
											.setVal(sqlMRPCOMMON.prmHSP_NO, row.Item(sqlMRPCOMMON.itmHSP_NO).ToString)			'入退院番号
											.setVal(sqlMRPCOMMON.prmCH_NO, row.Item(sqlMRPCOMMON.itmCH_NO).ToString)			'科歴番号
											.setVal(sqlMRP050R000.prmHSP_DAYS, row.Item(sqlMRP050R000.itmHSP_DAYS).ToString)	'在院日数
											.execNonQuery()
										End With
									End If
								Next
							Else
								'キー情報からワークへ
								.execNonQuery()
							End If
						Case ENUM_SQLTYPE.UPD, ENUM_SQLTYPE.UPD_SUM, ENUM_SQLTYPE.UPD_FROM, ENUM_SQLTYPE.UPD_TO
							Me.setSql(db, SqlType)
							.execNonQuery()

						Case ENUM_SQLTYPE.UPD_REC_Pat	 'ワーク更新(カルテ管理状況)
							Select Case clsMRPCOMMON.getLendItemUnitCd(clsConst.Enum_Lenditem.MedicalRecord)
								Case clsConst.Enum_LendUnit.Each_Patient
									Me.setSql(db, ENUM_SQLTYPE.UPD_REC_Pat)
								Case clsConst.Enum_LendUnit.Each_Hosp
									Me.setSql(db, ENUM_SQLTYPE.UPD_REC_Hsp)
								Case clsConst.Enum_LendUnit.Each_Dept
									Me.setSql(db, ENUM_SQLTYPE.UPD_REC_Ch)
								Case Else
									Continue For
							End Select
							.execNonQuery()
						Case ENUM_SQLTYPE.UPD_REC_Hsp, ENUM_SQLTYPE.UPD_REC_Ch
							Continue For
						Case Else

					End Select
				Next
			End With
			Return True
		Catch ex As Exception
			Throw
		Finally
			row = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' SQL文/パラメータ設定
	''' </summary>
	''' <param name="db">clsDB</param>
	''' <param name="type">ENUM_SQLTYPE</param>
	''' <remarks>
	''' 2010/11/22 新規作成　ACS)常包<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overridable Sub setSql(ByVal db As clsDB, ByRef type As ENUM_SQLTYPE)
		clsSysMst.logEx(XCM.clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, "setSql", clsMRPCOMMON.CST_LOG_PRODUCT, CST_LOG_CLASS, "SQL文/パラメータ設定")
		Try
			With db
				Select Case type
					Case ENUM_SQLTYPE.INS
						If Me.pDgv IsNot Nothing Then	'一覧からワークへ
							.setSQL(sqlMRP050R000.sqlIns)
							.setParam(sqlMRPCOMMON.prmDSPORDER, clsDB.Enum_dbType.dbInt)			'表示順
							.setParam(sqlMRPCOMMON.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
							.setParam(sqlMRPCOMMON.prmHSP_NO, clsDB.Enum_dbType.dbNVarChar)		'入退院歴番号
							.setParam(sqlMRPCOMMON.prmCH_NO, clsDB.Enum_dbType.dbNVarChar)		'科歴番号
							.setParam(sqlMRP050R000.prmHSP_DAYS, clsDB.Enum_dbType.dbNVarChar)	'在院日数
						Else							'キー情報からワークへ
							If Me.pHspNo = 0 AndAlso Me.pChNo = 0 Then
								.setSQL(sqlMRP050R000.sqlIns_Key_P)	   '患者単位
							ElseIf Me.pHspNo > 0 AndAlso Me.pChNo = 0 Then
								.setSQL(sqlMRP050R000.sqlIns_Key_PH)   '入退院歴単位
								.setParam(sqlMRPCOMMON.prmHSP_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
								.setVal(sqlMRPCOMMON.prmHSP_NO, Me.pHspNo, False)
							ElseIf Me.pHspNo > 0 AndAlso Me.pChNo > 0 Then
								.setSQL(sqlMRP050R000.sqlIns_Key_PHC)  '科歴単位
								.setParam(sqlMRPCOMMON.prmHSP_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
								.setParam(sqlMRPCOMMON.prmCH_NO, clsDB.Enum_dbType.dbInt)		'科歴番号
								.setVal(sqlMRPCOMMON.prmHSP_NO, Me.pHspNo, False)
								.setVal(sqlMRPCOMMON.prmCH_NO, Me.pChNo, False)
							End If
							.setParam(sqlMRPCOMMON.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
							.setVal(sqlMRPCOMMON.prmPATIENT_NO, Me.pPatientNo, False)
							'在院日数計算用
							.setParam(sqlMRP040R000.prmSYSDATE, clsDB.Enum_dbType.dbDateTime)						'システム日付
							.setParam(sqlMRP040R000.prmNISUU_INIT, clsDB.Enum_dbType.dbInt)							'在院日数の初期値
							.setParam(sqlMRP040R000.prmNISUU_PLUS, clsDB.Enum_dbType.dbInt)							'在院日数の計算
							.setVal(sqlMRP040R000.prmSYSDATE, Now().ToString("yyyy/MM/dd"))							'システム日付
							.setVal(sqlMRP040R000.prmNISUU_INIT, clsSysMst.ctlEnvData.getEnv(datEnv.Enum_ENV.ENV_00006), False)	'在院日数の初期値
							Dim val As Integer = clsSysMst.ctlEnvData.getEnv(datEnv.Enum_ENV.ENV_00004)
							If val = 2 Then val = 0
							.setVal(sqlMRP040R000.prmNISUU_PLUS, val, False)										'在院日数の計算
						End If
					Case ENUM_SQLTYPE.UPD			 'ワークをトランで更新
						.setSQL(sqlMRP050R000.sqlUpd)
						.setParam(sqlMRPCOMMON.prmENV_AGE, clsDB.Enum_dbType.dbNVarChar)								'年齢項目取得フラグ
						.setVal(sqlMRPCOMMON.prmENV_AGE, clsSysMst.ctlEnvData.getEnv(datEnv.Enum_ENV.ENV_00050))	'年齢項目取取得フラグ
					Case ENUM_SQLTYPE.UPD_REC_Pat	 'カルテ管理状況(患者単位)
						.setSQL(String.Format(sqlMRP050R000.sqlUpd_REC, sqlMRP050R000.sqlJoin_Pat))
					Case ENUM_SQLTYPE.UPD_REC_Hsp	 'カルテ管理状況(入退院単位)
						.setSQL(String.Format(sqlMRP050R000.sqlUpd_REC, sqlMRP050R000.sqlJoin_Hsp))
					Case ENUM_SQLTYPE.UPD_REC_Ch	 'カルテ管理状況(科歴単位)
						.setSQL(String.Format(sqlMRP050R000.sqlUpd_REC, sqlMRP050R000.sqlJoin_Ch))
					Case ENUM_SQLTYPE.UPD_SUM		 'サマリ管理状況(科歴単位)
						.setSQL(sqlMRP050R000.sqlUpd_SUM)
					Case ENUM_SQLTYPE.UPD_FROM		 '転科元コード
						.setSQL(sqlMRP050R000.sqlUpdFromDept)
						.setParam(sqlMRPCOMMON.prmFIXED_CD, clsDB.Enum_dbType.dbNVarChar)								'固定コード
						.setVal(sqlMRPCOMMON.prmFIXED_CD, clsConst.Enum_DiscchargeCannel_Fix1.ChangeDept)
					Case ENUM_SQLTYPE.UPD_TO		 '転科先コード
						.setSQL(sqlMRP050R000.sqlUpdToDept)
						.setParam(sqlMRPCOMMON.prmFIXED_CD, clsDB.Enum_dbType.dbNVarChar)								'固定コード
						.setVal(sqlMRPCOMMON.prmFIXED_CD, clsConst.Enum_HspChannel_Fix1.ChangeDept)
					Case Else
						Return
				End Select
				'共通パラメータ
				.setParam(sqlMRPCOMMON.prmHOST_NM, clsDB.Enum_dbType.dbNVarChar)				'ホスト名
				.setVal(sqlMRPCOMMON.prmHOST_NM, clsConst.CST_HOST_NM)
				.setParam(sqlMRPCOMMON.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)		'更新者コード
				.setVal(sqlMRPCOMMON.prmLASTUPDUSER_CD, clsSysMst.getLoginId)
				.setParam(sqlMRPCOMMON.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)			'更新日
				.setVal(sqlMRPCOMMON.prmLASTUPD_DT, DateTime.Now())
			End With
		Catch ex As Exception
			Throw
		End Try
	End Sub
#End Region

End Class
