﻿Imports System.Windows.Forms
Imports System.ComponentModel
Imports System.Globalization
Imports System.Reflection
'''---------------------------------------------
''' <summary>
''' 年月日入力ユーザーコントロール
''' </summary>
''' <remarks>
''' Copyright 2009 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
'''---------------------------------------------
Public Class BT_Date

#Region "コンスタント"

	Private Const CST_YYYYMMDD_MASK As String = "0000/00/00"
	Private Const CST_MMDD_MASK As String = "00/00"
	Private Const CST_YYMMDD_MASK As String = "A00/00/00"
'(A) STR V4-12056-000 004 20121218 ID 病歴大将V4PKG問題点NO.75 日付入力コントロールの上下対応
	Private Const WM_KEYDOWN As Integer = &H100		'KeyDownメッセージ
	Private Const WM_SYSKEYDOWN As Integer = &H104
'(A) END V4-12056-000 004 20121218

#End Region

#Region "変数"

	Private _dt As Date													'日付値
	Private _datestyle As Enum_DateStyle = Enum_DateStyle.Wst_Style		'表示スタイル(西暦or和暦)
	Private _todatelinkcontrol As String = Nothing						'TODateコントロール
	Private _caninput As Boolean = True									'True:入力可(通常表示),False:入力不可(ラベル表示)
	Private _comment As String = Nothing								'日本語での項目説明(検索条件保存で利用)

	Private GengouChar As String() = {"M", "T", "S", "H", " "}			 '元号略称

	'''----------------------------------------
	''' <summary>
	''' 入力年月日スタイル
	''' </summary>
	''' <remarks>
	''' 2010/11/04 新規作成 FJSK)荒川<BR/>
	''' </remarks>
	'''----------------------------------------
	Public Enum Enum_DateStyle As Integer		'年月日スタイル
		'''----------------------------------------
		''' <summary>西暦 yyyy/mm/dd</summary>
		'''----------------------------------------
		Wst_Style = 1	'西暦 yyyy/mm/dd
		'''----------------------------------------
		''' <summary>和暦 A90/90/90</summary>
		'''----------------------------------------
		Jpn_Style = 2	'和暦 A90/90/90
		'''----------------------------------------
		''' <summary>月日 mm/dd</summary>
		'''----------------------------------------
		Mon_Style = 3	'月日 mm/dd
	End Enum

#End Region

#Region "イベント"

	'テキストチェンジイベント追加
	Public Shadows Event TextChanged(ByVal sender As Object, ByVal e As System.EventArgs)

#End Region

#Region "プロパティ"

	'''----------------------------------------
	''' <summary>
	''' 入力された日付を文字型として返す
	''' </summary>
	''' <value></value>
	''' <returns>DateTime</returns>
	''' <remarks>
	''' 2009/11/06 新規作成　FJSK)柳原<BR/>
	''' </remarks>
	'''----------------------------------------
	Public Shadows ReadOnly Property Text() As String
		Get
			If _dt = Nothing Then
				Return Nothing
			Else
				Select Case _datestyle
					Case Enum_DateStyle.Wst_Style
						Return _dt.ToString(clsConst.CST_YYYYMMDD_FORMAT)
					Case Enum_DateStyle.Jpn_Style
						Return CvWareki(_dt)
					Case Enum_DateStyle.Mon_Style
						Return _dt.ToString(clsConst.CST_MMDD_FORMAT)
					Case Else
						Return Nothing
				End Select
			End If
		End Get
	End Property

	'''----------------------------------------
	''' <summary>
	''' 現在表示されている日付を文字型として返す
	''' </summary>
	''' <value></value>
	''' <returns>DateTime</returns>
	''' <remarks>
	''' 2010/01/26 新規作成　FJSK)柳原<BR/>
	''' </remarks>
	'''----------------------------------------
	Public ReadOnly Property DisplayText() As String
		Get
			Dim chk As Integer = chkData()		'日付型チェック
			If chk = 1 Then
				Return Me.mst001BT_Date.Text	'入力ＯＫの場合
			Else
				Return Nothing					'未入力,入力ＮＧの場合
			End If
		End Get
	End Property

	'''----------------------------------------
	''' <summary>
	''' 日付の取得・表示、選択日付を返す
	''' </summary>
	''' <value></value>
	''' <returns>DateTime</returns>
	''' <remarks>
	''' 2009/11/06 新規作成　FJSK)柳原<BR/>
	''' </remarks>
	'''----------------------------------------
	<Browsable(True), _
	Description("入力した日付のDate型"), _
	Category("カスタムプロパティ")> _
	Public Property DateValue() As Date
		Get
			Return _dt
		End Get
		Set(ByVal value As Date)
			_dt = value
			If value = Nothing Then
				Me.mst001BT_Date.Text = ""
			Else
				Select Case _datestyle
					Case Enum_DateStyle.Wst_Style
						Me.mst001BT_Date.Text = _dt.ToString(clsConst.CST_YYYYMMDD_FORMAT)
					Case Enum_DateStyle.Jpn_Style
						Me.mst001BT_Date.Text = CvWareki(_dt)
					Case Enum_DateStyle.Mon_Style
						Me.mst001BT_Date.Text = _dt.ToString(clsConst.CST_MMDD_FORMAT)
					Case Else
						Me.mst001BT_Date.Text = ""
				End Select
			End If
			Me.lbl003BT_Date.Text = Me.mst001BT_Date.Text	'ラベルに表示用テキストをセット
		End Set
	End Property

	'''----------------------------------------
	''' <summary>
	''' 日付入力・表示形式
	''' </summary>
	''' <value></value>
	''' <returns></returns>
	''' <remarks>
	''' 2009/11/06 新規作成　FJSK)柳原<BR/>
	''' </remarks>
	'''----------------------------------------
	<Browsable(True), _
	Description("日付入力・表示形式"), _
	  DefaultValue(GetType(Enum_DateStyle), "Wst_Style"), _
	Category("カスタムプロパティ")> _
	Public Property DateStyle() As Enum_DateStyle
		Get
			Return (_datestyle)
		End Get
		Set(ByVal value As Enum_DateStyle)
			_datestyle = value
			Select Case value
				Case Enum_DateStyle.Wst_Style
					Me.mst001BT_Date.Mask = CST_YYYYMMDD_MASK
					Me.mst001BT_Date.Width = 87
				Case Enum_DateStyle.Jpn_Style
					Me.mst001BT_Date.Mask = CST_YYMMDD_MASK
					Me.mst001BT_Date.Width = 79
				Case Enum_DateStyle.Mon_Style
					Me.mst001BT_Date.Mask = CST_MMDD_MASK
					Me.mst001BT_Date.Width = 47
				Case Else
					Me.mst001BT_Date.Mask = CST_YYYYMMDD_MASK
					Me.mst001BT_Date.Width = 87
			End Select
			Me.Width = Me.mst001BT_Date.Width + Me.btn002BT_Date.Width
			Me.btn002BT_Date.Location = New System.Drawing.Point(Me.mst001BT_Date.Width, Me.btn002BT_Date.Location.Y)
		End Set
	End Property

	'''---------------------------------------------
	''' <summary>
	''' 日付入力From-To形式の場合のTo側のコントロールを指定する
	''' </summary>
	''' <value></value>
	''' <returns></returns>
	''' <remarks>
	''' 2010/05/31 新規作成　FJSK)柳原<BR/>
	''' </remarks>
	'''---------------------------------------------
	<Browsable(True), _
	 Description("To側のコントロールを指定します"), _
	 DefaultValue(vbNullString), _
	 Category("カスタムプロパティ")> _
	Property ToDateLinkControl() As String
		Get
			Return _todatelinkcontrol
		End Get
		Set(ByVal Value As String)
			_todatelinkcontrol = Value
		End Set
	End Property

	'''----------------------------------------
	''' <summary>
	''' 入力可・不可設定
	''' </summary>
	''' <value>True:入力可，False:入力不可</value>
	''' <returns></returns>
	''' <remarks>
	''' 2010/02/17 新規作成　FJSK)柳原<BR/>
	''' </remarks>
	'''----------------------------------------
	<Browsable(True), _
	Description("True:入力可，False:入力不可"), _
	DefaultValue(True), _
	Category("カスタムプロパティ")> _
	Public Property CanInput() As Boolean
		Get
			Return (_caninput)
		End Get
		Set(ByVal value As Boolean)
			_caninput = value
			If Me.DesignMode = False Then
				If _caninput = True Then				'入力可の場合ラベルを無効化
					Me.mst001BT_Date.ReadOnly = False
					Me.btn002BT_Date.Enabled = True
					Me.TabStop = True
					Me.mst001BT_Date.BackColor = Nothing
				Else									'入力不可の場合ラベルを有効化
					Me.mst001BT_Date.ReadOnly = True
					Me.btn002BT_Date.Enabled = False
					Me.TabStop = False
					Me.mst001BT_Date.BackColor = clsConst.CST_INACTIVE_BACK_COLOR
				End If
			End If
		End Set
	End Property

	'''----------------------------------------
	''' <summary>
	''' 項目説明
	''' </summary>
	''' <value>項目説明</value>
	''' <returns></returns>
	''' <remarks>
	''' 2010/02/17 新規作成　FJSK)柳原<BR/>
	''' </remarks>
	'''----------------------------------------
	<Browsable(True), _
	Description("項目説明"), _
	DefaultValue(vbNullString), _
	Category("カスタムプロパティ")> _
	Public Property Comment() As String
		Get
			Return (_comment)
		End Get
		Set(ByVal value As String)
			_comment = value
		End Set
	End Property

#End Region

#Region "イベント"

'(D) STR V4-12056-000 026 20121218 ID 病歴大将V4PKG問題点NO.75 日付入力コントロールの上下対応
	' '''---------------------------------------------
	' ''' <summary>
	' ''' MaskedTextBoxキー入力イベント
	' ''' </summary>
	' ''' <remarks>
	' ''' 2009/11/06 新規作成　FJSK)柳原<BR/>
	' ''' </remarks>
	' '''---------------------------------------------
	'Private Sub mst001BT_Date_KeyDown(ByVal sender As Object, ByVal e As System.Windows.Forms.KeyEventArgs) Handles mst001BT_Date.KeyDown
	'	Try
	'		If Me.CanInput = True Then
	'			If e.KeyCode = Keys.F1 Then
	'				If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
	'					CType(Me.TopLevelControl, frmBase).log(clsSysMst.logLevel.NRM, MethodBase.GetCurrentMethod.Name, "MaskedTextBoxキー入力イベント START")
	'				End If
	'				dspCalendarForm()
	'			End If
	'		End If
	'	Catch ex As Exception
	'		If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
	'			CType(Me.TopLevelControl, frmBase).ErrorProc(ex)
	'		End If
	'	End Try
	'End Sub
'(D) END V4-12056-000 026 20121218

	'''---------------------------------------------
	''' <summary>
	''' カレンダーボタンクリック処理
	''' </summary>
	''' <param name="sender"></param>
	''' <param name="e"></param>
	''' <remarks>
	''' 2009/11/06 新規作成　FJSK)柳原<BR/>
	''' </remarks>
	'''---------------------------------------------
	Private Sub btn002BT_Date_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btn002BT_Date.Click
		If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
			CType(Me.TopLevelControl, frmBase).log(clsSysMst.logLevel.NRM, MethodBase.GetCurrentMethod.Name, "カレンダーボタンクリック処理 START")
		End If
		Try
			dspCalendarForm()
		Catch ex As Exception
			If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
				CType(Me.TopLevelControl, frmBase).ErrorProc(ex)
			End If
		End Try
	End Sub

	'''---------------------------------------------
	''' <summary>
	''' マウスクリック時、カーソル位置を先頭に
	''' </summary>
	''' <param name="sender"></param>
	''' <param name="e"></param>
	''' <remarks>
	''' 2009/12/22 新規作成　FJSK)柳原<BR/>
	''' </remarks>
	'''---------------------------------------------
	Private Sub mst001BT_Date_MouseClick(ByVal sender As Object, ByVal e As System.Windows.Forms.MouseEventArgs) Handles mst001BT_Date.MouseClick
		If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
			CType(Me.TopLevelControl, frmBase).log(clsSysMst.logLevel.DBG, MethodBase.GetCurrentMethod.Name, "マウスクリック時、カーソル位置を先頭に START")
		End If
		Try
			If String.IsNullOrEmpty(Trim(Replace(Me.mst001BT_Date.Text, "/", ""))) Then		'未入力の場合
				Me.mst001BT_Date.SelectionStart = 0											'カーソルを先頭へ
			End If
		Catch ex As Exception
			If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
				CType(Me.TopLevelControl, frmBase).ErrorProc(ex)
			End If
		End Try
	End Sub

#End Region

#Region "メソッド"

	'''---------------------------------------------
	''' <summary>
	''' カレンダー画面を表示する
	''' </summary>
	''' <remarks>
	''' 2009/11/06 新規作成　FJSK)柳原<BR/>
	''' </remarks>
	'''---------------------------------------------
	Private Sub dspCalendarForm()
		If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
			CType(Me.TopLevelControl, frmBase).log(clsSysMst.logLevel.DBG, MethodBase.GetCurrentMethod.Name, "カレンダー画面表示する START")
		End If
		Try
			Me.mst001BT_Date.Focus()							'先にMaskedTextBoxへFocus移動

			Dim myForm As frmBase = Me.TopLevelControl
			Dim ctlXCM010F010 As XCM010F010
			If _dt = Nothing Then
				ctlXCM010F010 = New XCM010F010(Me)			'当日でカレンダー画面表示
			Else
				ctlXCM010F010 = New XCM010F010(_dt, Me)	'指定日でカレンダー画面表示
			End If
			myForm.nextForm(ctlXCM010F010)
			Me.TopLevelControl.Enabled = False					'画面を無効(有効化はbackCalendar内で実施)
		Catch ex As Exception
			Throw
		End Try
	End Sub

	'''---------------------------------------------
	''' <summary>
	''' 西暦→和暦変換(A00/00/00形式)
	''' </summary>
	''' <param name="pDate"></param>
	''' <remarks>
	''' 2009/11/30 新規作成　FJSK)柳原<BR/>
	''' </remarks>
	'''---------------------------------------------
	Private Function CvWareki(ByVal pDate As DateTime) As String
		If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
			CType(Me.TopLevelControl, frmBase).log(clsSysMst.logLevel.DBG, MethodBase.GetCurrentMethod.Name, "西暦→和暦変換(A00/00/00形式) Start")
		End If
		Dim sRet As String = Nothing
		Try
			Dim cal As JapaneseCalendar = New JapaneseCalendar()
			sRet = GengouChar(cal.GetEra(pDate) - 1) & cal.GetYear(pDate).ToString("00") & "/" & cal.GetMonth(pDate).ToString("00") & "/" & cal.GetDayOfMonth(pDate).ToString("00")
		Catch ex As Exception
			Throw
		End Try
		Return sRet
	End Function

	'''---------------------------------------------
	''' <summary>
	''' mst001BT_Dateに入力された日付型のチェック
	''' </summary>
	''' <returns>
	''' 0:未入力
	''' 1:チェックOK
	''' -1:日付として認識できない
	''' -2:カレンダー表示不可(最小日付以下)
	''' -3:カレンダー表示不可(最大日付以上)
	''' </returns>
	''' <remarks>
	''' 2009/12/27 新規作成　FJSK)柳原<BR/>
	''' </remarks>
	'''---------------------------------------------
	Public Function chkData() As Integer
		If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
			CType(Me.TopLevelControl, frmBase).log(clsSysMst.logLevel.DBG, MethodBase.GetCurrentMethod.Name, "mst001BT_Dateに入力された日付型のチェック Start")
		End If
		Try
			If String.IsNullOrEmpty(Trim(Replace(Me.mst001BT_Date.Text, "/", ""))) Then		'未入力の場合
				Return 0
			Else
				Dim dt As DateTime
				Dim flg As Boolean = False
				Try
					'S00/00/00が来たときのためにTry~Chatchを使用する
					'エラーとなった場合は不正の日付として扱う
					flg = DateTime.TryParse(Me.mst001BT_Date.Text, dt)
				Catch ex As Exception
					flg = False
				End Try

				If flg Then
					Select Case True
						Case dt < clsConst.DATE_MIN		'カレンダー表示不可(最小日付以下)の場合
							Return -2
						Case dt > clsConst.DATE_MAX		'カレンダー表示不可(最大日付以上)の場合
							Return -3
						Case Else
							Return 1
					End Select
				Else	'日付として認識できない場合
					If Me.DateStyle = Enum_DateStyle.Mon_Style Then
						'2/29固定なら（うるう年）未来に進みうるう年を検索する
						If DateTime.TryParse("2000/" & Me.mst001BT_Date.Text, dt) Then
							Return 1
						End If
					End If
					Return -1
				End If
			End If
			Return 0
		Catch ex As Exception
			Throw
		End Try
	End Function

	'''---------------------------------------------
	''' <summary>
	''' 月設定
	''' </summary>
	''' <remarks>
	''' 2011/02/04 新規作成 FJSK)荒川<BR/>
	''' </remarks>
	'''---------------------------------------------
	Private Sub setMonth(ByRef _dta As DateTime)
		Try
			'If DateTime.TryParse(_dt.Year.ToString & Me.mst001BT_Date.Text, _dta) = False Then
			'End If
			DateTime.TryParse("2000/" & Me.mst001BT_Date.Text, _dta)
		Catch ex As Exception
			Throw
		End Try
	End Sub

'(A) STR V4-15015-000 017 2014/03/31 ID)荒川 未登録部分がなければ病名テキストの末尾を選択する対応
	'''---------------------------------------------
	''' <summary>
	''' 日付テキストの選択処理（テキストコントロール）
	''' </summary>
	''' <remarks>
	''' 2014/03/31 新規作成 ID)荒川<BR/>
	''' </remarks>
	'''---------------------------------------------
	Public Sub textSelect(_startindex As Integer, _length As Integer)
		Try
			Me.mst001BT_Date.Select(_startindex, _length)
		Catch ex As Exception
			Throw
		End Try
	End Sub
'(A) STR V4-15015-000 017 2014/03/31 ID)荒川 未登録部分がなければ病名テキストの末尾を選択する対応

#End Region

#Region "オーバーライドメソッド"

'(A) STR V4-12056-000 073 20121218 ID 病歴大将V4PKG問題点NO.75 日付入力コントロールの上下対応
	''' ---------------------------------------------
	''' <summary>
	''' コマンドキー処理　F1と上下キー
	''' ※KeyDownでは処理後にコントロールデフォルト動作が動作してしてまうため、
	''' 　カーソル制御が不可能でした。なので、ProcessCmdKeyで処理を横取りして、
	''' 　処理を記述。それに伴いもともとKeyDown処理にあったF1キー処理を移行
	''' </summary>
	''' <param name="msg"></param>
	''' <param name="KeyData"></param>
	''' <returns></returns>
	''' <remarks>
	''' 2012/12/18 新規作成 ID
	''' </remarks>
	''' ---------------------------------------------
	Protected Overrides Function ProcessCmdKey(ByRef msg As Message, ByVal KeyData As Keys) As Boolean
		Try
			If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
				CType(Me.TopLevelControl, frmBase).log(clsSysMst.logLevel.NRM, MethodBase.GetCurrentMethod.Name, "MaskedTextBoxキー入力イベント START")
			End If

			If msg.Msg = WM_KEYDOWN OrElse msg.Msg = WM_SYSKEYDOWN Then	'KEYDOWN時
				Dim key As Keys = KeyData And Keys.KeyCode
				Select Case True
					Case KeyData.Equals(Keys.F1)
						If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
							CType(Me.TopLevelControl, frmBase).log(clsSysMst.logLevel.NRM, MethodBase.GetCurrentMethod.Name, "MaskedTextBoxキー入力イベント START")
						End If
						dspCalendarForm()
						Return True
					Case KeyData.Equals(Keys.Up) OrElse KeyData.Equals(Keys.Down)
						' 上下ボタンに反応して、日付を加算する
						Dim beforeDte As Date = DateValue
						Dim beforePos As Integer = Me.mst001BT_Date.SelectionStart
						Dim value As Integer = IIf(KeyData.Equals(Keys.Up) = True, 1, -1)

						If DateValue.Equals(Nothing) = True Then
							DateValue = Now()
						End If
						'Select Case beforePos
						'	Case Is <= 4
						'		' 年部分
						'		DateValue = DateValue.AddYears(value)
						'	Case Is <= 7
						'		' 月部分
						'		DateValue = DateValue.AddMonths(value)
						'	Case Else
						'		' 日部分
						'		DateValue = DateValue.AddDays(value)
						'End Select
						DateValue = DateValue.AddDays(value)

						' 最小値、最大値対応
						If Date.Compare(DateValue, clsConst.DATE_MIN) < 0 Then DateValue = clsConst.DATE_MIN
						If Date.Compare(DateValue, clsConst.DATE_MAX) > 0 Then DateValue = clsConst.DATE_MAX

						' 文字列選択位置を基に戻す
						Me.mst001BT_Date.SelectionStart = beforePos
						Return True
					Case Else
				End Select
			End If
'(M) STR V4-12056-000 004 20130111 ID 病歴大将V4PKG問題点NO.75 日付入力コントロールの上下対応
'			MyBase.ProcessCmdKey(msg, KeyData)
			Return MyBase.ProcessCmdKey(msg, KeyData)
'(M) END V4-12056-000 004 20130111
		Catch ex As Exception
			If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
				CType(Me.TopLevelControl, frmBase).ErrorProc(ex)
			Else
				MessageBox.Show(ex.Message)
			End If
		End Try
	End Function
'(A) END V4-12056-000 073 20121218

	'''---------------------------------------------
	''' <summary>
	''' MaskedTextBox入力チェック処理
	''' </summary>
	''' <param name="e"></param>
	''' <remarks>
	''' 2009/12/27 新規作成　FJSK)柳原<BR/>
	''' </remarks>
	'''---------------------------------------------
	Protected Overrides Sub OnValidating(ByVal e As System.ComponentModel.CancelEventArgs)
		If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
			CType(Me.TopLevelControl, frmBase).log(clsSysMst.logLevel.DBG, MethodBase.GetCurrentMethod.Name, "MaskedTextBox入力チェック処理 START")
		End If
		Try
			MyBase.OnValidating(e)

			'デザインモード中は通常処理しない
			If Me.DesignMode Then
				Exit Sub
			End If

			If CType(Me.TopLevelControl, frmBase).ActiveControl.CausesValidation = False Then	'Validateを行わない場合はチェック処理終了
				Exit Sub
			End If

			Dim chk As Integer = chkData()		'日付型チェック
			Select Case chk
				Case 0		'未入力の場合
					_dt = Nothing
					RaiseEvent TextChanged(Me, e)

					If Not CType(Me.TopLevelControl, frmBase)._validateFlg Then
						'_validateFlg=Falseが通常。　Trueの場合はForm.ValidateChildren実行中
						CType(Me.TopLevelControl, frmBase).clearMsgBar()			'メッセージクリア
					End If
				Case 1		'入力ＯＫの場合
					If Me.DateStyle <> Enum_DateStyle.Mon_Style Then
						DateTime.TryParse(Me.mst001BT_Date.Text, _dt)
					Else
						Me.setMonth(_dt)
					End If

					'H01/01/01　を　S64/01/01に変更するために入力した値をDateValueに設定する
					Me.DateValue = _dt
					RaiseEvent TextChanged(Me, e)

					If Not CType(Me.TopLevelControl, frmBase)._validateFlg Then
						'_validateFlg=Falseが通常。　Trueの場合はForm.ValidateChildren実行中
						CType(Me.TopLevelControl, frmBase).clearMsgBar()			'メッセージクリア
					End If
				Case -1		'入力ＮＧの場合
					CType(Me.TopLevelControl, frmBase).showMsgBar("S0009", frmBase.Enum_MsgIcon.Err)	 '正しい日付を入力してください
					CType(Me.TopLevelControl, frmBase)._validateCtl = Me
					e.Cancel = True
				Case -2		'カレンダー表示不可(最小日付以下)の場合
					CType(Me.TopLevelControl, frmBase).showMsgBar("S0011", frmBase.Enum_MsgIcon.Err)	 '入力可能な最小日付を下回っています。
					CType(Me.TopLevelControl, frmBase)._validateCtl = Me
					e.Cancel = True
				Case -3		'カレンダー表示不可(最大日付以上)の場合
					CType(Me.TopLevelControl, frmBase).showMsgBar("S0012", frmBase.Enum_MsgIcon.Err)	 '入力可能な最大日付を超えています。
					CType(Me.TopLevelControl, frmBase)._validateCtl = Me
					e.Cancel = True
			End Select
		Catch ex As Exception
			If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
				CType(Me.TopLevelControl, frmBase).ErrorProc(ex)
			End If
		Finally
			Me.lbl003BT_Date.Text = Me.mst001BT_Date.Text	'ラベルに表示用テキストをセット
		End Try
	End Sub

	'''---------------------------------------------
	''' <summary>
	''' 編集開始時処理
	''' </summary>
	''' <param name="e"></param>
	''' <remarks>
	''' 2010/02/17 新規作成　FJSK)柳原<BR/>
	''' </remarks>
	'''---------------------------------------------
	Protected Overrides Sub OnEnter(ByVal e As System.EventArgs)
		If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
			CType(Me.TopLevelControl, frmBase).log(clsSysMst.logLevel.DBG, MethodBase.GetCurrentMethod.Name, "編集開始時処理 START")
		End If
		Try
			MyBase.OnEnter(e)
			If Me.DesignMode = False AndAlso _caninput = True Then
				Me.mst001BT_Date.BackColor = clsConst.CST_ACTIVE_BACK_COLOR			'MaskedTextBoxの背景色を変える
				Me.mst001BT_Date.Select()											'MaskedTextBoxを選択
				Me.mst001BT_Date.SelectAll()										'選択状態にする
			End If
		Catch ex As Exception
			If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
				CType(Me.TopLevelControl, frmBase).ErrorProc(ex)
			End If
		End Try
	End Sub

	'''---------------------------------------------
	''' <summary>
	''' 編集終了時処理
	''' </summary>
	''' <param name="e"></param>
	''' <remarks>
	''' 2010/02/17 新規作成　FJSK)柳原<BR/>
	''' </remarks>
	'''---------------------------------------------
	Protected Overrides Sub OnLeave(ByVal e As System.EventArgs)
		If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
			CType(Me.TopLevelControl, frmBase).log(clsSysMst.logLevel.DBG, MethodBase.GetCurrentMethod.Name, "編集終了時処理 Start")
		End If
		Try
			MyBase.OnLeave(e)
			If Me.DesignMode = False AndAlso _caninput = True Then
				Me.mst001BT_Date.BackColor = Nothing		'MaskedTextBoxの背景色を戻す

				'ToDate設定
				If String.IsNullOrEmpty(_todatelinkcontrol) = False Then	'Link先が設定されている場合
					Dim chk As Integer = chkData()		'日付型チェック
					If chk = 1 Then
						Dim ctl As Control() = Me.Parent.Controls.Find(_todatelinkcontrol, True)		'コントロールを取得
						If ctl.Length > 0 AndAlso CType(ctl(0), BT_Date).DateValue = Nothing Then		'コントロールが見つかった場合
							If Me.DateStyle <> Enum_DateStyle.Mon_Style Then
								DateTime.TryParse(Me.mst001BT_Date.Text, CType(ctl(0), BT_Date).DateValue)
							Else
								Me.setMonth(CType(ctl(0), BT_Date).DateValue)
							End If
						Else
							'一つ上のコントロールを検索してない場合はTopLevelContorol階層まで登る
							ctl = Me.TopLevelControl.Controls.Find(_todatelinkcontrol, True)
							If ctl.Length > 0 AndAlso CType(ctl(0), BT_Date).DateValue = Nothing Then
								If Me.DateStyle <> Enum_DateStyle.Mon_Style Then
									DateTime.TryParse(Me.mst001BT_Date.Text, CType(ctl(0), BT_Date).DateValue)
								Else
									Me.setMonth(CType(ctl(0), BT_Date).DateValue)
								End If
							End If
						End If
					End If
				End If
			End If
		Catch ex As Exception
			If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
				CType(Me.TopLevelControl, frmBase).ErrorProc(ex)
			End If
		End Try
	End Sub

#End Region

End Class
