﻿Imports XCM
''' ---------------------------------------------
''' <summary>
''' 共通処理_バーコードデータクラス
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public NotInheritable Class datBARCODE
	Public Patient_No As String			'患者番号
	Public Dept_Cd As String			'診療科コード
	Public Byoreki_No As String			'病歴番号
	Public Hsp_Dt As String				'入院日、退院日
End Class

'(A) STR V4-12064-000 030 20130104 ID)平井(貸出管理バーコード対応)
''' ---------------------------------------------
''' <summary>
''' 共通処理_バーコードデータクラス（貸出管理）
''' </summary>
''' <remarks>
''' Copyright 2013 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public NotInheritable Class datLENDBARCODE
	Public Patient_No As String			'患者番号
	Public MngItem_Cd As String			'管理物コード
	Public Div1_Cd As String			'区分１コード
	Public Div2_Cd As String			'区分２コード
	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' </summary>
	''' <remarks>
	''' 2013/01/04 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub New()
		Patient_No = String.Empty
		MngItem_Cd = String.Empty
		Div1_Cd = String.Empty
		Div2_Cd = String.Empty
	End Sub
End Class
'(A) END V4-12064-000 030 20130104

''' ---------------------------------------------
''' <summary>
''' 共通処理_バーコード
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public NotInheritable Class clsBarcode

#Region "コンスタント"
	Private Const C_PATIENT_NO_LENGTH As Integer = 10
'(M) STR V4-12064-000 004 20130104 ID)平井(貸出管理バーコード対応)
'	Private Const C_PATIENT_NO_ORDER As String = "I"
	Public Const C_PATIENT_NO_ORDER As String = "I"
'(M) END V4-12064-000 004 20130104
	Private Const C_DEPT_CD_ORDER As String = "K"
	Private Const C_DATE_ORDER As String = "D"
	Private Const C_DEPT_CD_LENGTH As Integer = 2
	Private Const C_DATE_LENGTH As Integer = 8
'(A) STR V4-12064-000 006 20121227 ID)平井(貸出管理バーコード対応)
	Private Const C_MNGITEM_CD_LENGTH As Integer = 2
	Private Const C_MNGITEM_CD_ORDER As String = "M"
	Private Const C_DIV_CD_CMB_LENGTH As Integer = 4
	Private Const C_DIV_CD_DATE_LENGTH As Integer = 8
'(A) END V4-12064-000 006 20121227
#End Region

#Region "変数"

	''' <summary>
	''' いいえ（０）、はい（１）
	''' </summary>
	Private Enum ENUM_YesNo As Integer
		''' <summary>いいえ</summary>
		No = 0
		''' <summary></summary>
		Yes = 1
	End Enum

#End Region

	''' ---------------------------------------------
	''' <summary>
	''' バーコードデータ取得処理（値を各項目に設定）
	''' </summary>
	''' <param name="strValue">バーコードリーダより取得した文字列</param>
	''' <returns>バーコードデータクラス</returns>
	''' <remarks>
	''' 2010/11/02 新規作成　CS)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getBarcode(ByVal strValue As String) As datBARCODE
		Try
			' バーコード１０桁（１：はいの場合、患者番号＝７桁、病歴番号＝３桁）
			Dim iBarcode_10 As Integer = ENUM_YesNo.No
			' バーコードＩＤ（患者番号の桁数）
			Dim iBarcode_Patient_No_Length As Integer = 0
			' バーコード順（Ｉ＝患者番号、Ｋ＝診療科コード、Ｄ＝日付　の並び順）
			Dim strBarcode_IKD As String = clsSysMst.ctlEnvData.getEnv(datEnv.Enum_ENV.ENV_00092)

			Dim dat As datBARCODE = New datBARCODE
			Dim iAllLength As Integer = 0

			' 動作環境設定のバーコード患者番号桁数
			If Not Integer.TryParse(clsSysMst.ctlEnvData.getEnv(datEnv.Enum_ENV.ENV_00091), iBarcode_Patient_No_Length) OrElse _
			   iBarcode_Patient_No_Length < 1 OrElse _
			   iBarcode_Patient_No_Length > 10 Then
				' 設定なしなら、１０桁に固定
				iBarcode_Patient_No_Length = C_PATIENT_NO_LENGTH
			End If
			' バーコード順の組合せ３文字の内、要素が欠けている場合
			If strBarcode_IKD.Length = 3 AndAlso _
			   strBarcode_IKD.Contains(C_PATIENT_NO_ORDER) AndAlso _
			   strBarcode_IKD.Contains(C_DEPT_CD_ORDER) AndAlso _
			   strBarcode_IKD.Contains(C_DATE_ORDER) Then
			Else
				' バーコード順は「Ｉ＝患者番号」→「Ｋ＝診療科コード」→「Ｄ＝日付」に固定
				strBarcode_IKD = C_PATIENT_NO_ORDER & C_DEPT_CD_ORDER & C_DATE_ORDER
			End If
			' 入力したバーコードが１０桁未満の場合、先に１０桁でゼロパディング
			If strValue.Length < C_PATIENT_NO_LENGTH Then
				strValue = strValue.PadLeft(C_PATIENT_NO_LENGTH, "0")
			End If
			' 入力したバーコードが１０桁の場合
			If strValue.Length = C_PATIENT_NO_LENGTH Then
				' 動作環境設定のバーコードの桁数が１０桁（患者番号＝７桁、病歴番号＝３桁）
				If Integer.TryParse(clsSysMst.ctlEnvData.getEnv(datEnv.Enum_ENV.ENV_00090), iBarcode_10) AndAlso iBarcode_10 = ENUM_YesNo.Yes Then
					' 「はい」の場合、患者番号と病歴番号に分解する
					dat.Patient_No = strValue.Substring(0, 7)	'患者番号＝７桁
					dat.Byoreki_No = strValue.Substring(7, 3)	'病歴番号＝３桁
				Else
					' 「いいえ」の場合、そのまま患者番号とする
					dat.Patient_No = strValue
				End If
			Else
				' 患者番号、診療科コード、日付に分解する
				For i As Integer = 0 To strBarcode_IKD.Length - 1
					Select Case strBarcode_IKD.Substring(i, 1)
						Case C_PATIENT_NO_ORDER
							' 患者番号
							If strValue.Length < iAllLength + iBarcode_Patient_No_Length Then
								Return Nothing
							End If
							dat.Patient_No = strValue.Substring(iAllLength, iBarcode_Patient_No_Length)
							iAllLength += iBarcode_Patient_No_Length
						Case C_DEPT_CD_ORDER
							' 診療科コード
							If strValue.Length < iAllLength + C_DEPT_CD_LENGTH Then
								Return Nothing
							End If
							dat.Dept_Cd = strValue.Substring(iAllLength, C_DEPT_CD_LENGTH)
							iAllLength += C_DEPT_CD_LENGTH
						Case C_DATE_ORDER
							' 入院日、退院日
							If strValue.Length < iAllLength + C_DATE_LENGTH Then
								Return Nothing
							End If
							Dim strDate As String = strValue.Substring(iAllLength, C_DATE_LENGTH)
							strDate = strDate.Substring(0, 4) & "/" & strDate.Substring(4, 2) & "/" & strDate.Substring(6, 2)
							Dim dtCheck As Date
							If Not Date.TryParse(strDate, dtCheck) OrElse _
							   dtCheck > System.Data.SqlTypes.SqlDateTime.MaxValue.Value OrElse _
							   dtCheck < System.Data.SqlTypes.SqlDateTime.MinValue.Value Then
								Return Nothing
							End If
							dat.Hsp_Dt = strDate
							iAllLength += C_DATE_LENGTH
					End Select
				Next
				' 桁数エラー
				If strValue.Length <> iAllLength Then
					Return Nothing
				End If
			End If
			' 患者番号を１０桁でゼロパディング
			dat.Patient_No = dat.Patient_No.PadLeft(C_PATIENT_NO_LENGTH, "0")
			Return dat
		Catch ex As Exception
			Throw
		End Try
	End Function

'(A) STR V4-12064-000 192 20130201 ID)平井(貸出管理バーコード対応)
	''' ---------------------------------------------
	''' <summary>
	''' バーコードデータ取得処理（値を各項目に設定）（貸出管理）
	''' </summary>
	''' <param name="strValue">バーコードリーダより取得した文字列</param>
	''' <param name="dtMngItem">管理物マスタデータテーブル</param>
	''' <returns>バーコードデータクラス</returns>
	''' <remarks>
	''' 2013/01/04 新規作成　ID)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getLendBarcode(ByVal strValue As String, ByVal dtMngItem As DataTable) As datLENDBARCODE
		Dim cliLtm_Div1 As clsLTM_DIV1
		Dim cliLtm_Div2 As clsLTM_DIV2
		Dim cliLtm_MngItem As clsLTM_MNGITEM
		Dim dt As DataTable
		Try
			Dim dr() As DataRow
			' バーコード順　"MI"の組合せ2文字（Ｉ＝患者番号、Ｍ＝管理物コード）
			Dim strBarcode_MI As String = clsSysMst.ctlEnvData.getEnv(datEnv.Enum_ENV.ENV_00105)
			' バーコード患者番号開始位置
			Dim iPatient_No_Start As Integer = clsSysMst.ctlEnvData.getEnv(datEnv.Enum_ENV.ENV_00106)
			' バーコード患者番号終了位置
			Dim iPatient_No_End As Integer = clsSysMst.ctlEnvData.getEnv(datEnv.Enum_ENV.ENV_00107)
			' 管理物コード長
			Dim iMngItem_Cd_Length As Integer = C_MNGITEM_CD_LENGTH
			' 患者番号長
			Dim iPatient_No_Length As Integer = 0
			' 区分１コード長
			Dim iDiv1_Cd_Length As Integer = 0
			' 区分２コード長
			Dim iDiv2_Cd_Length As Integer = 0

			Dim dat As datLENDBARCODE = New datLENDBARCODE

			' 値が空の場合
			If String.IsNullOrEmpty(strValue) Then
				Return Nothing
			End If
			' ■管理物コード、患者番号■
			' 管理物コードの最大長取得
			cliLtm_MngItem = New clsLTM_MNGITEM
			dt = cliLtm_MngItem.getMngItemCdMaxLength()
			If dt Is Nothing OrElse
				dt.Rows.Count = 0 OrElse
				CType(dt.Rows(0)(sqlLTM_MNGITEM.itmMAX_LENGTH).ToString, Integer) <= 0 Then
				Return Nothing
			End If
			iMngItem_Cd_Length = CType(dt.Rows(0)(sqlLTM_MNGITEM.itmMAX_LENGTH).ToString, Integer)
			If dt IsNot Nothing Then dt.Dispose()
			' 動作環境設定のバーコード患者番号桁数
			If (iPatient_No_End - iPatient_No_Start + 1) > C_PATIENT_NO_LENGTH Then
				iPatient_No_Length = C_PATIENT_NO_LENGTH
			Else
				iPatient_No_Length = iPatient_No_End - iPatient_No_Start + 1
			End If
			If iPatient_No_Length <= 0 Then
				Return Nothing
			End If
			' バーコード順より値設定
			If strBarcode_MI.Length = 2 Then
				If strValue.Length < (iPatient_No_Length + iMngItem_Cd_Length) Then
					Return Nothing
				End If
				Select Case strBarcode_MI
					' 管理物コード＋患者番号
					Case C_MNGITEM_CD_ORDER & C_PATIENT_NO_ORDER
						dat.MngItem_Cd = strValue.Substring(0, iMngItem_Cd_Length)
						dat.Patient_No = strValue.Substring(iMngItem_Cd_Length, iPatient_No_Length)
						' 患者番号＋管理物コード
					Case C_PATIENT_NO_ORDER & C_MNGITEM_CD_ORDER
						dat.Patient_No = strValue.Substring(0, iPatient_No_Length)
						dat.MngItem_Cd = strValue.Substring(iPatient_No_Length, iMngItem_Cd_Length)
					Case Else
						Return Nothing
				End Select
			Else
				If strValue.Length < iPatient_No_Length Then
					Return Nothing
				End If
				' 患者番号のみ
'(M) STR V4-15010-000 013 2014/04/11 ID)鐘井 貸出管理レベルアップ４次開発　バーコード対応
'				dat.Patient_No = strValue
				Dim Patient_No As String = String.Empty
				Dim Div1Div2_Cd As String = String.Empty

				' 患者番号
				Patient_No = strValue.Substring(0, iPatient_No_Length)
				Patient_No = Patient_No.PadLeft(iPatient_No_End, "0")
				Patient_No = Patient_No.PadRight(C_PATIENT_NO_LENGTH, "0")
				' 区分１、区分２
				Div1Div2_Cd = strValue.Substring(iPatient_No_Length, strValue.Length - iPatient_No_Length)
				dat.Patient_No = Patient_No & Div1Div2_Cd
'(M) END V4-15010-000 013 2014/04/11 ID)鐘井 貸出管理レベルアップ４次開発　バーコード対応
				iMngItem_Cd_Length = 0
			End If
			' 患者番号ゼロサプレス
			If Not String.IsNullOrEmpty(dat.Patient_No) Then
				' 患者番号を１０桁でゼロパディング
				dat.Patient_No = dat.Patient_No.PadLeft(iPatient_No_End, "0")
				dat.Patient_No = dat.Patient_No.PadRight(C_PATIENT_NO_LENGTH, "0")
			End If
			' ■管理物コード単位の処理（区分１．区分２）■
			If String.IsNullOrEmpty(dat.MngItem_Cd) Then
				Return dat
			End If
			' 管理物検索
			dr = dtMngItem.Select(sqlLTM_MNGITEM.itmMNGITEM_CD & " = '" & dat.MngItem_Cd & "'")
			If dr Is Nothing OrElse
				dr.Length = 0 Then
				' 管理物なし
				Return Nothing
			End If
			' 区分１
			If Not String.IsNullOrEmpty(dr(0)(sqlLTM_MNGITEM.itmDIV1TITLE).ToString) Then
				If dr(0)(sqlLTM_MNGITEM.itmDIV1TEXT_FLG).ToString = CType(clsConst.Enum_DivType_Flg.Cmb_Type, String) Then
					' コンボコードの最大長を取得
					cliLtm_Div1 = New clsLTM_DIV1
					dt = cliLtm_Div1.getDiv1CdMaxLength(dat.MngItem_Cd)
					If dt Is Nothing OrElse
						dt.Rows.Count = 0 Then
						Return Nothing
					End If
					iDiv1_Cd_Length = CType(dt.Rows(0)(sqlLTM_DIV1.itmMAX_LENGTH).ToString, Integer)
					If dt IsNot Nothing Then dt.Dispose()
					If strValue.Length < (iPatient_No_Length + iMngItem_Cd_Length + iDiv1_Cd_Length) OrElse
						iDiv1_Cd_Length <= 0 Then
						Return Nothing
					End If
					' コンボ型
					dat.Div1_Cd = strValue.Substring(iMngItem_Cd_Length + iPatient_No_Length, iDiv1_Cd_Length).TrimEnd()
					iDiv1_Cd_Length = iDiv1_Cd_Length
				ElseIf dr(0)(sqlLTM_MNGITEM.itmDIV1TEXT_FLG).ToString = CType(clsConst.Enum_DivType_Flg.Date_Type, String) Then
					If strValue.Length < (iPatient_No_Length + iMngItem_Cd_Length + C_DIV_CD_DATE_LENGTH) Then
						Return Nothing
					End If
					' 日付型
					Dim strDate As String = strValue.Substring(iMngItem_Cd_Length + iPatient_No_Length, C_DIV_CD_DATE_LENGTH)
					strDate = strDate.Substring(0, 4) & "/" &
								strDate.Substring(4, 2) & "/" &
								strDate.Substring(6, 2)
					Dim dtDiv1 As Date
					If Date.TryParse(strDate, dtDiv1) Then
						dat.Div1_Cd = dtDiv1.ToString("yyyy/MM/dd")
						iDiv1_Cd_Length = C_DIV_CD_DATE_LENGTH
					Else
						Return Nothing
					End If
				Else
					' テキストはエラー
					Return Nothing
				End If
			End If
			' 区分２
			If Not String.IsNullOrEmpty(dr(0)(sqlLTM_MNGITEM.itmDIV2TITLE).ToString) Then
				If dr(0)(sqlLTM_MNGITEM.itmDIV2TEXT_FLG).ToString = CType(clsConst.Enum_DivType_Flg.Cmb_Type, String) Then
					' コンボコードの最大長を取得
					cliLtm_Div2 = New clsLTM_DIV2
					dt = cliLtm_Div2.getDiv2CdMaxLength(dat.MngItem_Cd)
					If dt Is Nothing OrElse
						dt.Rows.Count = 0 Then
						Return Nothing
					End If
					iDiv2_Cd_Length = CType(dt.Rows(0)(sqlLTM_DIV2.itmMAX_LENGTH).ToString, Integer)
					If dt IsNot Nothing Then dt.Dispose()
					If strValue.Length < (iPatient_No_Length + iMngItem_Cd_Length + iDiv1_Cd_Length + iDiv2_Cd_Length) OrElse
						iDiv2_Cd_Length <= 0 Then
						Return Nothing
					End If
					' コンボ型
					dat.Div2_Cd = strValue.Substring(iMngItem_Cd_Length + iPatient_No_Length + iDiv1_Cd_Length, iDiv2_Cd_Length).TrimEnd()
				ElseIf dr(0)(sqlLTM_MNGITEM.itmDIV2TEXT_FLG).ToString = CType(clsConst.Enum_DivType_Flg.Date_Type, String) Then
					If strValue.Length < (iPatient_No_Length + iMngItem_Cd_Length + iDiv1_Cd_Length + C_DIV_CD_DATE_LENGTH) Then
						Return Nothing
					End If
					' 日付型
					Dim strDate As String = strValue.Substring(iMngItem_Cd_Length + iPatient_No_Length + iDiv1_Cd_Length, C_DIV_CD_DATE_LENGTH)
					strDate = strDate.Substring(0, 4) & "/" &
								strDate.Substring(4, 2) & "/" &
								strDate.Substring(6, 2)
					Dim dtDiv2 As Date
					If Date.TryParse(strDate, dtDiv2) Then
						dat.Div2_Cd = dtDiv2.ToString("yyyy/MM/dd")
					Else
						Return Nothing
					End If
				Else
					' テキストはエラー
					Return Nothing
				End If
			End If

			Return dat

		Catch ex As Exception
			Throw
		Finally
			dt = Nothing
			cliLtm_Div1 = Nothing
			cliLtm_Div2 = Nothing
			cliLtm_MngItem = Nothing
		End Try
	End Function
'(A) END V4-12064-000 192 20130201

End Class
