﻿Imports XCM
Imports System.Reflection

''' ---------------------------------------------
''' <summary>
''' 医療費明細情報アクセスクラス
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public NotInheritable Class clsMTI_MED_COST_DETAILS
	Implements IDisposable

#Region "解放処理"

	'解放処理時使用＊＊
	Protected disposed As Boolean = False

	''' ---------------------------------------------	
	''' <summary>
	''' Dispose（解放処理）※外からはよばない
	''' </summary>
	''' <param name="disposing"></param>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overloads Sub Dispose(ByVal disposing As Boolean)
		If Not Me.disposed Then
		End If
		Me.disposed = True
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）
	''' </summary>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overloads Sub Dispose() Implements IDisposable.Dispose
		Dispose(True)
		GC.SuppressFinalize(Me)
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）※外からはよばない
	''' </summary>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overrides Sub Finalize()
		Dispose(False)
		MyBase.Finalize()
	End Sub
#End Region

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' </summary>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Sub New()
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String) As Boolean
		Try
			Return Not String.IsNullOrWhiteSpace(pPatientNo)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDate">日付</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pMedCostDate As String) As Boolean
		Dim dtMedCostDate As Date
		Try
			Return chkParam(pPatientNo) AndAlso Date.TryParse(pMedCostDate, dtMedCostDate)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDateSince">開始日</param>
	''' <param name="pMedCostDateUntil">終了日</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pMedCostDateSince As String, ByVal pMedCostDateUntil As String) As Boolean
		Dim dtMedCostDate As Date
		Try
			Return chkParam(pPatientNo, pMedCostDateSince) AndAlso Date.TryParse(pMedCostDateUntil, dtMedCostDate)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDate">日付</param>
	''' <param name="pSerialNo">連番</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pMedCostDate As String, ByVal pSerialNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo, pMedCostDate) AndAlso (pSerialNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の医療費明細情報を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の医療費明細情報（ArrayList内にdatMTI_MED_COST_DETAILS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsPatient(ByVal pPatientNo As String) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getMedCostDetailsPatient(db, pPatientNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の医療費明細情報を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の医療費明細情報（ArrayList内にdatMTI_MED_COST_DETAILS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsPatient(ByVal db As clsDB, ByVal pPatientNo As String) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_MED_COST_DETAILS.sqlSelMedCostDetails_Patient)	'SELECT文設定
			db.setParam(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setVal(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, pPatientNo)
			iRet = db.execQuery(GetType(datMTI_MED_COST_DETAILS_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の医療費明細情報を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の医療費明細情報</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsPatientDa(ByVal pPatientNo As String) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getMedCostDetailsPatientDa(db, pPatientNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の医療費明細情報を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の医療費明細情報</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsPatientDa(ByVal db As clsDB, ByVal pPatientNo As String) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_MED_COST_DETAILS.sqlSelMedCostDetails_Patient)
			db.setParamDa(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setValDa(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, pPatientNo)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 開始日以降の医療費明細情報を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDateSince">開始日</param>
	''' <returns>開始日以降の医療費明細情報（ArrayList内にdatMTI_MED_COST_DETAILS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsSince(ByVal pPatientNo As String, ByVal pMedCostDateSince As String) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getMedCostDetailsSince(db, pPatientNo, pMedCostDateSince)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 開始日以降の医療費明細情報を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDateSince">開始日</param>
	''' <returns>開始日以降の医療費明細情報（ArrayList内にdatMTI_MED_COST_DETAILS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsSince(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pMedCostDateSince As String) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			Select Case True
				Case String.IsNullOrWhiteSpace(pMedCostDateSince)
					Return getMedCostDetailsPatient(db, pPatientNo)
				Case Not chkParam(pPatientNo, pMedCostDateSince)
					Return Nothing
				Case Else
			End Select

			db.setSQL(sqlMTI_MED_COST_DETAILS.sqlSelMedCostDetails_Since)	'SELECT文設定
			db.setParam(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)				'患者番号
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_SINCE, clsDB.Enum_dbType.dbDateTime)	'開始日
			db.setVal(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_SINCE, Date.Parse(pMedCostDateSince))
			iRet = db.execQuery(GetType(datMTI_MED_COST_DETAILS_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 開始日以降の医療費明細情報を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDateSince">開始日</param>
	''' <returns>開始日以降の医療費明細情報</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsSinceDa(ByVal pPatientNo As String, ByVal pMedCostDateSince As String) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getMedCostDetailsSinceDa(db, pPatientNo, pMedCostDateSince)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 開始日以降の医療費明細情報を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDateSince">開始日</param>
	''' <returns>開始日以降の医療費明細情報</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsSinceDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pMedCostDateSince As String) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'キーチェック
			Select Case True
				Case String.IsNullOrWhiteSpace(pMedCostDateSince)
					Return getMedCostDetailsPatientDa(db, pPatientNo)
				Case Not chkParam(pPatientNo, pMedCostDateSince)
					Return getMedCostDetailsPatientDa(db, pPatientNo).Clone
				Case Else
			End Select

			'SQL文設定
			db.setSQLDa(sqlMTI_MED_COST_DETAILS.sqlSelMedCostDetails_Since)
			db.setParamDa(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)			'患者番号
			db.setParamDa(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_SINCE, clsDB.Enum_dbType.dbDateTime)	'開始日
			db.setValDa(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_SINCE, Date.Parse(pMedCostDateSince))

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 日付範囲の医療費明細情報を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDateSince">開始日</param>
	''' <param name="pMedCostDateUntil">終了日</param>
	''' <returns>日付範囲の医療費明細情報（ArrayList内にdatMTI_MED_COST_DETAILS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsBetween(ByVal pPatientNo As String, ByVal pMedCostDateSince As String, ByVal pMedCostDateUntil As String) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getMedCostDetailsBetween(db, pPatientNo, pMedCostDateSince, pMedCostDateUntil)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 日付範囲の医療費明細情報を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDateSince">開始日</param>
	''' <param name="pMedCostDateUntil">終了日</param>
	''' <returns>日付範囲の医療費明細情報（ArrayList内にdatMTI_MED_COST_DETAILS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsBetween(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pMedCostDateSince As String, ByVal pMedCostDateUntil As String) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			Select Case True
				Case String.IsNullOrWhiteSpace(pMedCostDateUntil)
					Return getMedCostDetailsSince(db, pPatientNo, pMedCostDateSince)
				Case Not chkParam(pPatientNo, pMedCostDateSince, pMedCostDateUntil)
					Return Nothing
				Case Else
			End Select

			db.setSQL(sqlMTI_MED_COST_DETAILS.sqlSelMedCostDetails_Between)	'SELECT文設定
			db.setParam(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)				'患者番号
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_SINCE, clsDB.Enum_dbType.dbDateTime)	'開始日
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_UNTIL, clsDB.Enum_dbType.dbDateTime)	'終了日
			db.setVal(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_SINCE, Date.Parse(pMedCostDateSince))
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_UNTIL, Date.Parse(pMedCostDateUntil))
			iRet = db.execQuery(GetType(datMTI_MED_COST_DETAILS_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 日付範囲の医療費明細情報を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDateSince">開始日</param>
	''' <param name="pMedCostDateUntil">終了日</param>
	''' <returns>日付範囲の医療費明細情報</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsBetweenDa(ByVal pPatientNo As String, ByVal pMedCostDateSince As String, ByVal pMedCostDateUntil As String) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getMedCostDetailsBetweenDa(db, pPatientNo, pMedCostDateSince, pMedCostDateUntil)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 日付範囲の医療費明細情報を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDateSince">開始日</param>
	''' <param name="pMedCostDateUntil">終了日</param>
	''' <returns>日付範囲の医療費明細情報</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsBetweenDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pMedCostDateSince As String, ByVal pMedCostDateUntil As String) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'キーチェック
			Select Case True
				Case String.IsNullOrWhiteSpace(pMedCostDateUntil)
					Return getMedCostDetailsSinceDa(db, pPatientNo, pMedCostDateSince)
				Case Not chkParam(pPatientNo, pMedCostDateSince, pMedCostDateUntil)
					Return getMedCostDetailsPatientDa(db, pPatientNo).Clone
				Case Else
			End Select

			'SQL文設定
			db.setSQLDa(sqlMTI_MED_COST_DETAILS.sqlSelMedCostDetails_Between)
			db.setParamDa(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)			'患者番号
			db.setParamDa(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_SINCE, clsDB.Enum_dbType.dbDateTime)	'開始日
			db.setParamDa(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_UNTIL, clsDB.Enum_dbType.dbDateTime)	'終了日
			db.setValDa(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_SINCE, Date.Parse(pMedCostDateSince))
			db.setValDa(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_UNTIL, Date.Parse(pMedCostDateUntil))

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 医療費明細情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDate">日付</param>
	''' <param name="pSerialNo">連番</param>
	''' <returns>医療費明細情報クラス</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsOneRec(ByVal pPatientNo As String, ByVal pMedCostDate As String, ByVal pSerialNo As Integer) As datMTI_MED_COST_DETAILS_OneRec
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getMedCostDetailsOneRec(db, pPatientNo, pMedCostDate, pSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 医療費明細情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDate">日付</param>
	''' <param name="pSerialNo">連番</param>
	''' <returns>医療費明細情報クラス</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pMedCostDate As String, ByVal pSerialNo As Integer) As datMTI_MED_COST_DETAILS_OneRec
		Dim retDat As datMTI_MED_COST_DETAILS_OneRec = Nothing
		Dim arData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pMedCostDate, pSerialNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_MED_COST_DETAILS.sqlSelMedCostDetails_OneRec)	'SELECT文設定
			db.setParam(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE, clsDB.Enum_dbType.dbDateTime)	'医療費日付
			db.setParam(sqlMTI_MED_COST_DETAILS.prmSERIAL_NO, clsDB.Enum_dbType.dbInt)			'連番
			db.setVal(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE, Date.Parse(pMedCostDate))
			db.setVal(sqlMTI_MED_COST_DETAILS.prmSERIAL_NO, pSerialNo, False)
			iRet = db.execQuery(GetType(datMTI_MED_COST_DETAILS_OneRec), arData)	'値取得
			If iRet > 0 Then									   'レコードあり
				retDat = DirectCast(arData(0), datMTI_MED_COST_DETAILS_OneRec)
			Else
				retDat = Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 医療費明細情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDate">日付</param>
	''' <param name="pSerialNo">連番</param>
	''' <returns>医療費明細情報</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsOneRecDa(ByVal pPatientNo As String, ByVal pMedCostDate As String, ByVal pSerialNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getMedCostDetailsOneRecDa(db, pPatientNo, pMedCostDate, pSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 医療費明細情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDate">日付</param>
	''' <param name="pSerialNo">連番</param>
	''' <returns>医療費明細情報</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsOneRecDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pMedCostDate As String, ByVal pSerialNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'キーチェック
			If Not chkParam(pPatientNo, pMedCostDate, pSerialNo) Then
				Return getMedCostDetailsPatientDa(db, pPatientNo).Clone
			End If

			'SQL文設定
			db.setSQLDa(sqlMTI_MED_COST_DETAILS.sqlSelMedCostDetails_OneRec)						'SELECT文設定
			db.setParamDa(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE, clsDB.Enum_dbType.dbDateTime)	'医療費日付
			db.setParamDa(sqlMTI_MED_COST_DETAILS.prmSERIAL_NO, clsDB.Enum_dbType.dbInt)				'連番
			db.setValDa(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE, Date.Parse(pMedCostDate))
			db.setValDa(sqlMTI_MED_COST_DETAILS.prmSERIAL_NO, pSerialNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の医療費明細情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の医療費明細情報＋名称（ArrayList内にdatMTI_MED_COST_DETAILS_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsPlusPatient(ByVal pPatientNo As String) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getMedCostDetailsPlusPatient(db, pPatientNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の医療費明細情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の医療費明細情報＋名称（ArrayList内にdatMTI_MED_COST_DETAILS_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsPlusPatient(ByVal db As clsDB, ByVal pPatientNo As String) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_MED_COST_DETAILS.sqlSelMedCostDetails_Plus_Patient)	'SELECT文設定
			db.setParam(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setVal(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, pPatientNo)
			iRet = db.execQuery(GetType(datMTI_MED_COST_DETAILS_PLUS_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の医療費明細情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の医療費明細情報＋名称</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsPlusPatientDa(ByVal pPatientNo As String) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getMedCostDetailsPlusPatientDa(db, pPatientNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の医療費明細情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の医療費明細情報＋名称</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsPlusPatientDa(ByVal db As clsDB, ByVal pPatientNo As String) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_MED_COST_DETAILS.sqlSelMedCostDetails_Plus_Patient)
			db.setParamDa(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setValDa(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, pPatientNo)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 開始日以降の医療費明細情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDateSince">開始日</param>
	''' <returns>開始日以降の医療費明細情報＋名称（ArrayList内にdatMTI_MED_COST_DETAILS_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsPlusSince(ByVal pPatientNo As String, ByVal pMedCostDateSince As String) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getMedCostDetailsPlusSince(db, pPatientNo, pMedCostDateSince)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 開始日以降の医療費明細情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDateSince">開始日</param>
	''' <returns>開始日以降の医療費明細情報＋名称（ArrayList内にdatMTI_MED_COST_DETAILS_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsPlusSince(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pMedCostDateSince As String) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			Select Case True
				Case String.IsNullOrWhiteSpace(pMedCostDateSince)
					Return getMedCostDetailsPlusPatient(db, pPatientNo)
				Case Not chkParam(pPatientNo, pMedCostDateSince)
					Return Nothing
				Case Else
			End Select

			db.setSQL(sqlMTI_MED_COST_DETAILS.sqlSelMedCostDetails_Plus_Since)	'SELECT文設定
			db.setParam(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)				'患者番号
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_SINCE, clsDB.Enum_dbType.dbDateTime)	'開始日
			db.setVal(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_SINCE, Date.Parse(pMedCostDateSince))
			iRet = db.execQuery(GetType(datMTI_MED_COST_DETAILS_PLUS_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 開始日以降の医療費明細情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDateSince">開始日</param>
	''' <returns>開始日以降の医療費明細情報＋名称</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsPlusSinceDa(ByVal pPatientNo As String, ByVal pMedCostDateSince As String) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getMedCostDetailsPlusSinceDa(db, pPatientNo, pMedCostDateSince)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 開始日以降の医療費明細情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDateSince">開始日</param>
	''' <returns>開始日以降の医療費明細情報＋名称</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsPlusSinceDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pMedCostDateSince As String) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'キーチェック
			Select Case True
				Case String.IsNullOrWhiteSpace(pMedCostDateSince)
					Return getMedCostDetailsPlusPatientDa(db, pPatientNo)
				Case Not chkParam(pPatientNo, pMedCostDateSince)
					Return getMedCostDetailsPlusPatientDa(db, pPatientNo).Clone
				Case Else
			End Select

			'SQL文設定
			db.setSQLDa(sqlMTI_MED_COST_DETAILS.sqlSelMedCostDetails_Plus_Since)
			db.setParamDa(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)			'患者番号
			db.setParamDa(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_SINCE, clsDB.Enum_dbType.dbDateTime)	'開始日
			db.setValDa(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_SINCE, Date.Parse(pMedCostDateSince))

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 日付範囲の医療費明細情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDateSince">開始日</param>
	''' <param name="pMedCostDateUntil">終了日</param>
	''' <returns>日付範囲の医療費明細情報＋名称（ArrayList内にdatMTI_MED_COST_DETAILS_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsPlusBetween(ByVal pPatientNo As String, ByVal pMedCostDateSince As String, ByVal pMedCostDateUntil As String) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getMedCostDetailsPlusBetween(db, pPatientNo, pMedCostDateSince, pMedCostDateUntil)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 日付範囲の医療費明細情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDateSince">開始日</param>
	''' <param name="pMedCostDateUntil">終了日</param>
	''' <returns>日付範囲の医療費明細情報＋名称（ArrayList内にdatMTI_MED_COST_DETAILS_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsPlusBetween(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pMedCostDateSince As String, ByVal pMedCostDateUntil As String) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			Select Case True
				Case String.IsNullOrWhiteSpace(pMedCostDateUntil)
					Return getMedCostDetailsPlusSince(db, pPatientNo, pMedCostDateSince)
				Case Not chkParam(pPatientNo, pMedCostDateSince, pMedCostDateUntil)
					Return Nothing
				Case Else
			End Select

			db.setSQL(sqlMTI_MED_COST_DETAILS.sqlSelMedCostDetails_Plus_Between)	'SELECT文設定
			db.setParam(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)				'患者番号
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_SINCE, clsDB.Enum_dbType.dbDateTime)	'開始日
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_UNTIL, clsDB.Enum_dbType.dbDateTime)	'終了日
			db.setVal(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_SINCE, Date.Parse(pMedCostDateSince))
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_UNTIL, Date.Parse(pMedCostDateUntil))
			iRet = db.execQuery(GetType(datMTI_MED_COST_DETAILS_PLUS_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 日付範囲の医療費明細情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDateSince">開始日</param>
	''' <param name="pMedCostDateUntil">終了日</param>
	''' <returns>日付範囲の医療費明細情報＋名称</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsPlusBetweenDa(ByVal pPatientNo As String, ByVal pMedCostDateSince As String, ByVal pMedCostDateUntil As String) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getMedCostDetailsPlusBetweenDa(db, pPatientNo, pMedCostDateSince, pMedCostDateUntil)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 日付範囲の医療費明細情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDateSince">開始日</param>
	''' <param name="pMedCostDateUntil">終了日</param>
	''' <returns>日付範囲の医療費明細情報＋名称</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsPlusBetweenDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pMedCostDateSince As String, ByVal pMedCostDateUntil As String) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'キーチェック
			Select Case True
				Case String.IsNullOrWhiteSpace(pMedCostDateUntil)
					Return getMedCostDetailsPlusSinceDa(db, pPatientNo, pMedCostDateSince)
				Case Not chkParam(pPatientNo, pMedCostDateSince, pMedCostDateUntil)
					Return getMedCostDetailsPlusPatientDa(db, pPatientNo).Clone
				Case Else
			End Select

			'SQL文設定
			db.setSQLDa(sqlMTI_MED_COST_DETAILS.sqlSelMedCostDetails_Plus_Between)
			db.setParamDa(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)			'患者番号
			db.setParamDa(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_SINCE, clsDB.Enum_dbType.dbDateTime)	'開始日
			db.setParamDa(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_UNTIL, clsDB.Enum_dbType.dbDateTime)	'終了日
			db.setValDa(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_SINCE, Date.Parse(pMedCostDateSince))
			db.setValDa(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_UNTIL, Date.Parse(pMedCostDateUntil))

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 医療費明細情報＋名称を１件取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDate">日付</param>
	''' <param name="pSerialNo">連番</param>
	''' <returns>医療費明細情報＋名称クラス</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsPlusOneRec(ByVal pPatientNo As String, ByVal pMedCostDate As String, ByVal pSerialNo As Integer) As datMTI_MED_COST_DETAILS_PLUS_OneRec
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getMedCostDetailsPlusOneRec(db, pPatientNo, pMedCostDate, pSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 医療費明細情報＋名称を１件取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDate">日付</param>
	''' <param name="pSerialNo">連番</param>
	''' <returns>医療費明細情報＋名称クラス</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsPlusOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pMedCostDate As String, ByVal pSerialNo As Integer) As datMTI_MED_COST_DETAILS_PLUS_OneRec
		Dim retDat As datMTI_MED_COST_DETAILS_PLUS_OneRec = Nothing
		Dim arData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pMedCostDate, pSerialNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_MED_COST_DETAILS.sqlSelMedCostDetails_Plus_OneRec)	'SELECT文設定
			db.setParam(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE, clsDB.Enum_dbType.dbDateTime)	'医療費日付
			db.setParam(sqlMTI_MED_COST_DETAILS.prmSERIAL_NO, clsDB.Enum_dbType.dbInt)			'連番
			db.setVal(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE, Date.Parse(pMedCostDate))
			db.setVal(sqlMTI_MED_COST_DETAILS.prmSERIAL_NO, pSerialNo, False)
			iRet = db.execQuery(GetType(datMTI_MED_COST_DETAILS_PLUS_OneRec), arData)	'値取得
			If iRet > 0 Then									   'レコードあり
				retDat = DirectCast(arData(0), datMTI_MED_COST_DETAILS_PLUS_OneRec)
			Else
				retDat = Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 医療費明細情報＋名称を１件取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDate">日付</param>
	''' <param name="pSerialNo">連番</param>
	''' <returns>医療費明細情報＋名称</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsPlusOneRecDa(ByVal pPatientNo As String, ByVal pMedCostDate As String, ByVal pSerialNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getMedCostDetailsPlusOneRecDa(db, pPatientNo, pMedCostDate, pSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 医療費明細情報＋名称を１件取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDate">日付</param>
	''' <param name="pSerialNo">連番</param>
	''' <returns>医療費明細情報＋名称</returns>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostDetailsPlusOneRecDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pMedCostDate As String, ByVal pSerialNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'キーチェック
			If Not chkParam(pPatientNo, pMedCostDate, pSerialNo) Then
				Return getMedCostDetailsPlusPatientDa(db, pPatientNo).Clone
			End If

			'SQL文設定
			db.setSQLDa(sqlMTI_MED_COST_DETAILS.sqlSelMedCostDetails_Plus_OneRec)					'SELECT文設定
			db.setParamDa(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE, clsDB.Enum_dbType.dbDateTime)	'医療費日付
			db.setParamDa(sqlMTI_MED_COST_DETAILS.prmSERIAL_NO, clsDB.Enum_dbType.dbInt)				'連番
			db.setValDa(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE, Date.Parse(pMedCostDate))
			db.setValDa(sqlMTI_MED_COST_DETAILS.prmSERIAL_NO, pSerialNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の医療費明細情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelMedCostDetailsPatient(ByVal db As clsDB, ByVal pPatientNo As String)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "医療費明細情報アクセスクラス", "１患者分の医療費明細情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo) Then
				' 削除実行
				db.setSQL(sqlMTI_MED_COST_DETAILS.sqlDelMedCostDetails_Patient)	'DELETE文設定
				db.setParam(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
				db.setVal(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, pPatientNo)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 開始日以降の医療費明細情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDateSince">開始日</param>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelMedCostDetailsSince(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pMedCostDateSince As String)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "医療費明細情報アクセスクラス", "開始日以降の医療費明細情報を削除 Start")
		Try
			'キーチェック
			Select Case True
				Case String.IsNullOrWhiteSpace(pMedCostDateSince)
					execDelMedCostDetailsPatient(db, pPatientNo)
				Case chkParam(pPatientNo, pMedCostDateSince)
					' 削除実行
					db.setSQL(sqlMTI_MED_COST_DETAILS.sqlDelMedCostDetails_Since)	'DELETE文設定
					db.setParam(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)				'患者番号
					db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_SINCE, clsDB.Enum_dbType.dbDateTime)	'開始日
					db.setVal(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, pPatientNo)
					db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_SINCE, Date.Parse(pMedCostDateSince))
					db.execNonQuery(False)
				Case Else
			End Select
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 日付範囲の医療費明細情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDateSince">開始日</param>
	''' <param name="pMedCostDateUntil">終了日</param>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelMedCostDetailsBetween(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pMedCostDateSince As String, ByVal pMedCostDateUntil As String)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "医療費明細情報アクセスクラス", "日付範囲の医療費明細情報を削除 Start")
		Try
			'キーチェック
			Select Case True
				Case String.IsNullOrWhiteSpace(pMedCostDateUntil)
					execDelMedCostDetailsSince(db, pPatientNo, pMedCostDateSince)
				Case chkParam(pPatientNo, pMedCostDateSince, pMedCostDateUntil)
					' 削除実行
					db.setSQL(sqlMTI_MED_COST_DETAILS.sqlDelMedCostDetails_Between)	'DELETE文設定
					db.setParam(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)				'患者番号
					db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_SINCE, clsDB.Enum_dbType.dbDateTime)	'開始日
					db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_UNTIL, clsDB.Enum_dbType.dbDateTime)	'終了日
					db.setVal(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, pPatientNo)
					db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_SINCE, Date.Parse(pMedCostDateSince))
					db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE_UNTIL, Date.Parse(pMedCostDateUntil))
					db.execNonQuery(False)
				Case Else
			End Select
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 医療費明細情報１データを削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDate">日付</param>
	''' <param name="pSerialNo">連番</param>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelMedCostDetailsOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pMedCostDate As String, ByVal pSerialNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "医療費明細情報アクセスクラス", "医療費明細情報１データを削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pMedCostDate, pSerialNo) Then
				' 削除実行
				db.setSQL(sqlMTI_MED_COST_DETAILS.sqlDelMedCostDetails_OneRec)	'DELETE文設定
				db.setParam(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
				db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE, clsDB.Enum_dbType.dbDateTime)	'医療費日付
				db.setParam(sqlMTI_MED_COST_DETAILS.prmSERIAL_NO, clsDB.Enum_dbType.dbInt)			'連番
				db.setVal(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE, Date.Parse(pMedCostDate))
				db.setVal(sqlMTI_MED_COST_DETAILS.prmSERIAL_NO, pSerialNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 医療費明細情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pMedCostDetailsRec">医療費明細情報クラス</param>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsMedCostDetailsOneRec(ByVal db As clsDB, ByVal pMedCostDetailsRec As datMTI_MED_COST_DETAILS_OneRec) As Integer
		Try
			Return execInsMedCostDetailsOneRec(db, pMedCostDetailsRec, True)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 医療費明細情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pMedCostDetailsPlusRec">医療費明細情報＋名称クラス</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsMedCostDetailsOneRec(ByVal db As clsDB, ByVal pMedCostDetailsPlusRec As datMTI_MED_COST_DETAILS_PLUS_OneRec) As Integer
		Try
			Return execInsMedCostDetailsOneRec(db, pMedCostDetailsPlusRec, True)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 医療費明細情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pMedCostDetailsPlusRec">医療費明細情報＋名称クラス</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsMedCostDetailsOneRec(ByVal db As clsDB, ByVal pMedCostDetailsPlusRec As datMTI_MED_COST_DETAILS_PLUS_OneRec, ByVal bLastUpdate As Boolean) As Integer
		Dim pMedCostDetailsRec As datMTI_MED_COST_DETAILS_OneRec = Nothing
		Try
			If pMedCostDetailsPlusRec IsNot Nothing Then
				pMedCostDetailsRec = pMedCostDetailsPlusRec.OrgCopy
			End If
			Return execInsMedCostDetailsOneRec(db, pMedCostDetailsRec, bLastUpdate)
		Catch ex As Exception
			Throw
		Finally
			pMedCostDetailsRec = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 医療費明細情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pMedCostDetailsRec">医療費明細情報クラス</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/08 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsMedCostDetailsOneRec(ByVal db As clsDB, ByVal pMedCostDetailsRec As datMTI_MED_COST_DETAILS_OneRec, ByVal bLastUpdate As Boolean) As Integer
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "医療費明細情報アクセスクラス", "医療費明細情報１データを追加 Start")
		Try
			If pMedCostDetailsRec Is Nothing Then
				Return 0
			End If
			' INSERT文設定
			db.setSQL(sqlMTI_MED_COST_DETAILS.sqlInsMedCostDetails_OneRec)
			' 患者番号
			db.setParam(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmPATIENT_NO, pMedCostDetailsRec.PATIENT_NO)
			' 日付
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST_DATE, pMedCostDetailsRec.MED_COST_DATE)
			' 連番
			db.setParam(sqlMTI_MED_COST_DETAILS.prmSERIAL_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmSERIAL_NO, pMedCostDetailsRec.SERIAL_NO, False)
			' 診療科コード
			db.setParam(sqlMTI_MED_COST_DETAILS.prmDEPT_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmDEPT_CD, pMedCostDetailsRec.DEPT_CD)
			' 管理番号
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMNG_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMNG_NO, pMedCostDetailsRec.MNG_NO, False)
			' 医療費０１
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST01, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST01, pMedCostDetailsRec.MED_COST01, False)
			' 医療費０２
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST02, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST02, pMedCostDetailsRec.MED_COST02, False)
			' 医療費０３
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST03, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST03, pMedCostDetailsRec.MED_COST03, False)
			' 医療費０４
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST04, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST04, pMedCostDetailsRec.MED_COST04, False)
			' 医療費０５
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST05, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST05, pMedCostDetailsRec.MED_COST05, False)
			' 医療費０６
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST06, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST06, pMedCostDetailsRec.MED_COST06, False)
			' 医療費０７
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST07, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST07, pMedCostDetailsRec.MED_COST07, False)
			' 医療費０８
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST08, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST08, pMedCostDetailsRec.MED_COST08, False)
			' 医療費０９
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST09, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST09, pMedCostDetailsRec.MED_COST09, False)
			' 医療費１０
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST10, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST10, pMedCostDetailsRec.MED_COST10, False)
			' 医療費１１
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST11, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST11, pMedCostDetailsRec.MED_COST11, False)
			' 医療費１２
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST12, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST12, pMedCostDetailsRec.MED_COST12, False)
			' 医療費１３
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST13, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST13, pMedCostDetailsRec.MED_COST13, False)
			' 医療費１４
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST14, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST14, pMedCostDetailsRec.MED_COST14, False)
			' 医療費１５
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST15, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST15, pMedCostDetailsRec.MED_COST15, False)
			' 医療費１６
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST16, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST16, pMedCostDetailsRec.MED_COST16, False)
			' 医療費１７
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST17, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST17, pMedCostDetailsRec.MED_COST17, False)
			' 医療費１８
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST18, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST18, pMedCostDetailsRec.MED_COST18, False)
			' 医療費１９
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST19, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST19, pMedCostDetailsRec.MED_COST19, False)
			' 医療費２０
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST20, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST20, pMedCostDetailsRec.MED_COST20, False)
			' 医療費２１
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST21, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST21, pMedCostDetailsRec.MED_COST21, False)
			' 医療費２２
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST22, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST22, pMedCostDetailsRec.MED_COST22, False)
			' 医療費２３
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST23, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST23, pMedCostDetailsRec.MED_COST23, False)
			' 医療費２４
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST24, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST24, pMedCostDetailsRec.MED_COST24, False)
			' 医療費２５
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST25, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST25, pMedCostDetailsRec.MED_COST25, False)
			' 医療費２６
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST26, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST26, pMedCostDetailsRec.MED_COST26, False)
			' 医療費２７
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST27, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST27, pMedCostDetailsRec.MED_COST27, False)
			' 医療費２８
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST28, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST28, pMedCostDetailsRec.MED_COST28, False)
			' 医療費２９
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST29, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST29, pMedCostDetailsRec.MED_COST29, False)
			' 医療費３０
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST30, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST30, pMedCostDetailsRec.MED_COST30, False)
			' 医療費３１
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST31, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST31, pMedCostDetailsRec.MED_COST31, False)
			' 医療費３２
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST32, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST32, pMedCostDetailsRec.MED_COST32, False)
			' 医療費３３
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST33, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST33, pMedCostDetailsRec.MED_COST33, False)
			' 医療費３４
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST34, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST34, pMedCostDetailsRec.MED_COST34, False)
			' 医療費３５
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST35, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST35, pMedCostDetailsRec.MED_COST35, False)
			' 医療費３６
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST36, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST36, pMedCostDetailsRec.MED_COST36, False)
			' 医療費３７
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST37, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST37, pMedCostDetailsRec.MED_COST37, False)
			' 医療費３８
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST38, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST38, pMedCostDetailsRec.MED_COST38, False)
			' 医療費３９
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST39, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST39, pMedCostDetailsRec.MED_COST39, False)
			' 医療費４０
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST40, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST40, pMedCostDetailsRec.MED_COST40, False)
			' 医療費４１
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST41, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST41, pMedCostDetailsRec.MED_COST41, False)
			' 医療費４２
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST42, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST42, pMedCostDetailsRec.MED_COST42, False)
			' 医療費４３
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST43, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST43, pMedCostDetailsRec.MED_COST43, False)
			' 医療費４４
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST44, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST44, pMedCostDetailsRec.MED_COST44, False)
			' 医療費４５
			db.setParam(sqlMTI_MED_COST_DETAILS.prmMED_COST45, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmMED_COST45, pMedCostDetailsRec.MED_COST45, False)
			' 対診科情報
			db.setParam(sqlMTI_MED_COST_DETAILS.prmOTHER_DEPT_INFO, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmOTHER_DEPT_INFO, pMedCostDetailsRec.OTHER_DEPT_INFO)
			' データ取込日
			db.setParam(sqlMTI_MED_COST_DETAILS.prmDATA_CAPTURE_DT, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmDATA_CAPTURE_DT, pMedCostDetailsRec.DATA_CAPTURE_DT)
			' 新規登録日
			db.setParam(sqlMTI_MED_COST_DETAILS.prmNEW_REG_DT, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_MED_COST_DETAILS.prmNEW_REG_DT, pMedCostDetailsRec.NEW_REG_DT)
			' 更新者コード
			db.setParam(sqlMTI_MED_COST.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)
			If bLastUpdate OrElse String.IsNullOrEmpty(pMedCostDetailsRec.LASTUPDUSER_CD) Then
				' 更新者コード←ログインＩＤ
				db.setVal(sqlMTI_MED_COST.prmLASTUPDUSER_CD, clsSysMst.getLoginId)
			Else
				db.setVal(sqlMTI_MED_COST.prmLASTUPDUSER_CD, pMedCostDetailsRec.LASTUPDUSER_CD)
			End If
			' 最終更新日
			db.setParam(sqlMTI_MED_COST.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)
			If bLastUpdate OrElse pMedCostDetailsRec.LASTUPD_DT.Equals(Nothing) Then
				' 最終更新日←システム日付
				db.setVal(sqlMTI_MED_COST.prmLASTUPD_DT, Now())
			Else
				db.setVal(sqlMTI_MED_COST.prmLASTUPD_DT, pMedCostDetailsRec.LASTUPD_DT)
			End If
			' 追加実行
			Return db.execNonQuery(False)
		Catch ex As Exception
			Throw
		End Try
	End Function
End Class
