﻿Imports XCM
Imports System.Reflection

''' ---------------------------------------------
''' <summary>
''' 手術情報アクセスクラス
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public NotInheritable Class clsMTI_OPE
	Implements IDisposable

#Region "変数"

	' 手術一覧並び替え設定
	Private strOrderBy As String = sqlMTI_OPE.sqlOrder_By_Default

#End Region

#Region "解放処理"

	'解放処理時使用＊＊
	Protected disposed As Boolean = False

	''' ---------------------------------------------	
	''' <summary>
	''' Dispose（解放処理）※外からはよばない
	''' </summary>
	''' <param name="disposing"></param>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overloads Sub Dispose(ByVal disposing As Boolean)
		If Not Me.disposed Then
		End If
		Me.disposed = True
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）
	''' </summary>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overloads Sub Dispose() Implements IDisposable.Dispose
		Dispose(True)
		GC.SuppressFinalize(Me)
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）※外からはよばない
	''' </summary>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overrides Sub Finalize()
		Dispose(False)
		MyBase.Finalize()
	End Sub
#End Region

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' </summary>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Sub New()
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' </summary>
	''' <param name="pSort">手術一覧並び替え設定</param>
	''' <remarks>
	''' 2011/03/25 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Sub New(ByVal pSort As clsConst.Enum_SortOpe)
		Me.New()
		Select Case pSort
			Case clsConst.Enum_SortOpe.NoSort
				strOrderBy = sqlMTI_OPE.sqlOrder_By_NoSort
			Case clsConst.Enum_SortOpe.Sort
				strOrderBy = sqlMTI_OPE.sqlOrder_By_Sort
			Case clsConst.Enum_SortOpe.SortDivDt
				strOrderBy = sqlMTI_OPE.sqlOrder_By_SortDivDt
			Case Else
		End Select
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String) As Boolean
		Try
			Return Not String.IsNullOrWhiteSpace(pPatientNo)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo) AndAlso (pHspHistoryNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo, pHspHistoryNo) AndAlso (pChNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo, pHspHistoryNo, pChNo) AndAlso (pOpeSerialNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' SQL文の取得
	''' </summary>
	''' <param name="strSQL">SQL文</param>
	''' <returns>ORDER BY句を変更したSQL文</returns>
	''' <remarks>
	''' 2011/03/25 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function getSQL(ByVal strSQL As String) As String
		Try
			Return strSQL.Replace(sqlMTI_OPE.strORDER_BY, strOrderBy)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' DataRow より手術情報クラスを作成
	''' </summary>
	''' <param name="pRow">手術情報 DataRow</param>
	''' <returns>手術情報クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeRecFromDataRow(ByVal pRow As DataRow) As datMTI_OPE_OneRec
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "手術情報アクセスクラス", "DataRow より手術情報クラスを作成 Start")
		Dim retDat As datMTI_OPE_OneRec
		Dim hType As Type = Nothing
		Dim hFieldInfos As FieldInfo() = Nothing
		Dim objValue As Object = Nothing
		Dim bSetValue As Boolean = False
		Try
			' DataRow 無しの場合
			If pRow Is Nothing OrElse pRow.Table.Columns.Count = 0 Then
				Return Nothing
			End If

			' インスタンス生成
			retDat = New datMTI_OPE_OneRec

			' クラス要素の取得
			hType = retDat.GetType
			hFieldInfos = hType.GetFields(BindingFlags.GetField Or BindingFlags.Public Or BindingFlags.Instance Or BindingFlags.DeclaredOnly)

			' 値の取得および設定
			For Each aFieldInfo As FieldInfo In hFieldInfos
				' 値を取得
				If Not pRow.Table.Columns.Contains(aFieldInfo.Name) Then
					Continue For
				End If
				objValue = pRow(aFieldInfo.Name)
				' 値を設定
				If objValue IsNot Nothing AndAlso objValue IsNot DBNull.Value Then
					hType.InvokeMember(aFieldInfo.Name, _
					 BindingFlags.SetField Or BindingFlags.Public Or BindingFlags.Instance Or BindingFlags.DeclaredOnly, _
					 Nothing, _
					 retDat, _
					 New Object() {objValue})
					bSetValue = True
				End If
			Next
			If bSetValue Then
				Return retDat
			Else
				Return Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			hType = Nothing
			hFieldInfos = Nothing
			objValue = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' DataRow より手術情報＋名称クラスを作成
	''' </summary>
	''' <param name="pRow">手術情報 DataRow</param>
	''' <returns>手術情報＋名称クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpePlusRecFromDataRow(ByVal pRow As DataRow) As datMTI_OPE_PLUS_OneRec
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "手術情報アクセスクラス", "DataRow より手術情報＋名称クラスを作成 Start")
		Dim retDat As datMTI_OPE_PLUS_OneRec
		Dim hType As Type = Nothing
		Dim hFieldInfos As FieldInfo() = Nothing
		Dim objValue As Object = Nothing
		Dim bSetValue As Boolean = False
		Try
			' DataRow 無しの場合
			If pRow Is Nothing OrElse pRow.Table.Columns.Count = 0 Then
				Return Nothing
			End If

			' インスタンス生成
			retDat = New datMTI_OPE_PLUS_OneRec

			' クラス要素の取得
			hType = retDat.GetType
			hFieldInfos = hType.GetFields(BindingFlags.GetField Or BindingFlags.Public Or BindingFlags.Instance Or BindingFlags.DeclaredOnly)

			' 値の取得および設定
			For Each aFieldInfo As FieldInfo In hFieldInfos
				' 値を取得
				If Not pRow.Table.Columns.Contains(aFieldInfo.Name) Then
					Continue For
				End If
				objValue = pRow(aFieldInfo.Name)
				' 値を設定
				If objValue IsNot Nothing AndAlso objValue IsNot DBNull.Value Then
					hType.InvokeMember(aFieldInfo.Name, _
					 BindingFlags.SetField Or BindingFlags.Public Or BindingFlags.Instance Or BindingFlags.DeclaredOnly, _
					 Nothing, _
					 retDat, _
					 New Object() {objValue})
					bSetValue = True
				End If
			Next
			If bSetValue Then
				Return retDat
			Else
				Return Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			hType = Nothing
			hFieldInfos = Nothing
			objValue = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の手術情報を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の手術情報（ArrayList内にdatMTI_OPE_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpePatient(ByVal pPatientNo As String) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpePatient(db, pPatientNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の手術情報を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の手術情報（ArrayList内にdatMTI_OPE_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpePatient(ByVal db As clsDB, ByVal pPatientNo As String) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo) Then
				Return Nothing
			End If

			db.setSQL(getSQL(sqlMTI_OPE.sqlSelOpe_Patient))	'SELECT文設定
			db.setParam(sqlMTI_OPE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setVal(sqlMTI_OPE.prmPATIENT_NO, pPatientNo)
			iRet = db.execQuery(GetType(datMTI_OPE_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の手術情報を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の手術情報</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpePatientDa(ByVal pPatientNo As String) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpePatientDa(db, pPatientNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の手術情報を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の手術情報</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpePatientDa(ByVal db As clsDB, ByVal pPatientNo As String) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(getSQL(sqlMTI_OPE.sqlSelOpe_Patient))	'SELECT文設定

			db.setParamDa(sqlMTI_OPE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setValDa(sqlMTI_OPE.prmPATIENT_NO, pPatientNo)
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の手術情報を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の手術情報（ArrayList内にdatMTI_OPE_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeHsp(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpeHsp(db, pPatientNo, pHspHistoryNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の手術情報を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の手術情報（ArrayList内にdatMTI_OPE_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeHsp(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo) Then
				Return Nothing
			End If

			db.setSQL(getSQL(sqlMTI_OPE.sqlSelOpe_Hsp))	'SELECT文設定
			db.setParam(sqlMTI_OPE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_OPE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setVal(sqlMTI_OPE.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_OPE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			iRet = db.execQuery(GetType(datMTI_OPE_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の手術情報を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の手術情報</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeHspDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpeHspDa(db, pPatientNo, pHspHistoryNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の手術情報を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の手術情報</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeHspDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(getSQL(sqlMTI_OPE.sqlSelOpe_Hsp))	'SELECT文設定

			db.setParamDa(sqlMTI_OPE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_OPE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setValDa(sqlMTI_OPE.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_OPE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の手術情報を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の手術情報（ArrayList内にdatMTI_OPE_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeCh(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpeCh(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の手術情報を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の手術情報（ArrayList内にdatMTI_OPE_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeCh(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				Return Nothing
			End If

			db.setSQL(getSQL(sqlMTI_OPE.sqlSelOpe_Ch))	'SELECT文設定
			db.setParam(sqlMTI_OPE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_OPE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParam(sqlMTI_OPE.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setVal(sqlMTI_OPE.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_OPE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_OPE.prmCH_NO, pChNo, False)
			iRet = db.execQuery(GetType(datMTI_OPE_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の手術情報を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の手術情報</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeChDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpeChDa(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の手術情報を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の手術情報</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeChDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(getSQL(sqlMTI_OPE.sqlSelOpe_Ch))	'SELECT文設定

			db.setParamDa(sqlMTI_OPE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_OPE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParamDa(sqlMTI_OPE.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setValDa(sqlMTI_OPE.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_OPE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_OPE.prmCH_NO, pChNo, False)
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 手術情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <returns>手術情報クラス</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeOneRec(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer) As datMTI_OPE_OneRec
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpeOneRec(db, pPatientNo, pHspHistoryNo, pChNo, pOpeSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 手術情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <returns>手術情報クラス</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer) As datMTI_OPE_OneRec
		Dim retDat As datMTI_OPE_OneRec = Nothing
		Dim arData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo, pOpeSerialNo) Then
				Return Nothing
			End If

			db.setSQL(getSQL(sqlMTI_OPE.sqlSelOpe_OneRec))	'SELECT文設定
			db.setParam(sqlMTI_OPE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParam(sqlMTI_OPE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParam(sqlMTI_OPE.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
			db.setParam(sqlMTI_OPE.prmOPE_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'手術連番
			db.setVal(sqlMTI_OPE.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_OPE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_OPE.prmCH_NO, pChNo, False)
			db.setVal(sqlMTI_OPE.prmOPE_SERIAL_NO, pOpeSerialNo, False)
			iRet = db.execQuery(GetType(datMTI_OPE_OneRec), arData)	'値取得
			If iRet > 0 Then									   'レコードあり
				retDat = DirectCast(arData(0), datMTI_OPE_OneRec)
			Else
				retDat = Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 手術情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <returns>手術情報</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeOneRecDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpeOneRecDa(db, pPatientNo, pHspHistoryNo, pChNo, pOpeSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 手術情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <returns>手術情報</returns>
	''' <remarks>
	''' 2010/11/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpeOneRecDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(getSQL(sqlMTI_OPE.sqlSelOpe_OneRec))

			db.setParamDa(sqlMTI_OPE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_OPE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParamDa(sqlMTI_OPE.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setParamDa(sqlMTI_OPE.prmOPE_SERIAL_NO, clsDB.Enum_dbType.dbInt)		'手術連番
			db.setValDa(sqlMTI_OPE.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_OPE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_OPE.prmCH_NO, pChNo, False)
			db.setValDa(sqlMTI_OPE.prmOPE_SERIAL_NO, pOpeSerialNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の手術情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の手術情報＋名称（ArrayList内にdatMTI_OPE_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpePlusPatient(ByVal pPatientNo As String) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpePlusPatient(db, pPatientNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の手術情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の手術情報＋名称（ArrayList内にdatMTI_OPE_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpePlusPatient(ByVal db As clsDB, ByVal pPatientNo As String) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo) Then
				Return Nothing
			End If

			db.setSQL(getSQL(sqlMTI_OPE.sqlSelOpe_Plus_Patient))	'SELECT文設定
			db.setParam(sqlMTI_OPE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setVal(sqlMTI_OPE.prmPATIENT_NO, pPatientNo)
			iRet = db.execQuery(GetType(datMTI_OPE_PLUS_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の手術情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の手術情報＋名称</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpePlusPatientDa(ByVal pPatientNo As String) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpePlusPatientDa(db, pPatientNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の手術情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１患者分の手術情報＋名称</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpePlusPatientDa(ByVal db As clsDB, ByVal pPatientNo As String) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(getSQL(sqlMTI_OPE.sqlSelOpe_Plus_Patient))	'SELECT文設定

			db.setParamDa(sqlMTI_OPE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setValDa(sqlMTI_OPE.prmPATIENT_NO, pPatientNo)
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の手術情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の手術情報＋名称（ArrayList内にdatMTI_OPE_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpePlusHsp(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpePlusHsp(db, pPatientNo, pHspHistoryNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の手術情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の手術情報＋名称（ArrayList内にdatMTI_OPE_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpePlusHsp(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo) Then
				Return Nothing
			End If

			db.setSQL(getSQL(sqlMTI_OPE.sqlSelOpe_Plus_Hsp))	'SELECT文設定
			db.setParam(sqlMTI_OPE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_OPE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setVal(sqlMTI_OPE.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_OPE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			iRet = db.execQuery(GetType(datMTI_OPE_PLUS_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の手術情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の手術情報＋名称</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpePlusHspDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpePlusHspDa(db, pPatientNo, pHspHistoryNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の手術情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の手術情報＋名称</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpePlusHspDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(getSQL(sqlMTI_OPE.sqlSelOpe_Plus_Hsp))	'SELECT文設定

			db.setParamDa(sqlMTI_OPE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_OPE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setValDa(sqlMTI_OPE.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_OPE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の手術情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の手術情報＋名称（ArrayList内にdatMTI_OPE_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpePlusCh(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpePlusCh(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の手術情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の手術情報＋名称（ArrayList内にdatMTI_OPE_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpePlusCh(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				Return Nothing
			End If

			db.setSQL(getSQL(sqlMTI_OPE.sqlSelOpe_Plus_Ch))	'SELECT文設定
			db.setParam(sqlMTI_OPE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_OPE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParam(sqlMTI_OPE.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setVal(sqlMTI_OPE.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_OPE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_OPE.prmCH_NO, pChNo, False)
			iRet = db.execQuery(GetType(datMTI_OPE_PLUS_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の手術情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の手術情報＋名称</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpePlusChDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpePlusChDa(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の手術情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の手術情報＋名称</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpePlusChDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(getSQL(sqlMTI_OPE.sqlSelOpe_Plus_Ch))	'SELECT文設定

			db.setParamDa(sqlMTI_OPE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_OPE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParamDa(sqlMTI_OPE.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setValDa(sqlMTI_OPE.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_OPE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_OPE.prmCH_NO, pChNo, False)
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 手術情報＋名称を１件取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <returns>手術情報＋名称クラス</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpePlusOneRec(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer) As datMTI_OPE_PLUS_OneRec
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpePlusOneRec(db, pPatientNo, pHspHistoryNo, pChNo, pOpeSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 手術情報＋名称を１件取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <returns>手術情報＋名称クラス</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpePlusOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer) As datMTI_OPE_PLUS_OneRec
		Dim retDat As datMTI_OPE_PLUS_OneRec = Nothing
		Dim arData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo, pOpeSerialNo) Then
				Return Nothing
			End If

			db.setSQL(getSQL(sqlMTI_OPE.sqlSelOpe_Plus_OneRec))	'SELECT文設定
			db.setParam(sqlMTI_OPE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParam(sqlMTI_OPE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParam(sqlMTI_OPE.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
			db.setParam(sqlMTI_OPE.prmOPE_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'手術連番
			db.setVal(sqlMTI_OPE.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_OPE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_OPE.prmCH_NO, pChNo, False)
			db.setVal(sqlMTI_OPE.prmOPE_SERIAL_NO, pOpeSerialNo, False)
			iRet = db.execQuery(GetType(datMTI_OPE_PLUS_OneRec), arData)	'値取得
			If iRet > 0 Then									   'レコードあり
				retDat = DirectCast(arData(0), datMTI_OPE_PLUS_OneRec)
			Else
				retDat = Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 手術情報＋名称を１件取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <returns>手術情報＋名称</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpePlusOneRecDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOpePlusOneRecDa(db, pPatientNo, pHspHistoryNo, pChNo, pOpeSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 手術情報＋名称を１件取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <returns>手術情報＋名称</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOpePlusOneRecDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(getSQL(sqlMTI_OPE.sqlSelOpe_Plus_OneRec))

			db.setParamDa(sqlMTI_OPE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_OPE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParamDa(sqlMTI_OPE.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setParamDa(sqlMTI_OPE.prmOPE_SERIAL_NO, clsDB.Enum_dbType.dbInt)		'手術連番
			db.setValDa(sqlMTI_OPE.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_OPE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_OPE.prmCH_NO, pChNo, False)
			db.setValDa(sqlMTI_OPE.prmOPE_SERIAL_NO, pOpeSerialNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の手術情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelOpePatient(ByVal db As clsDB, ByVal pPatientNo As String)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "手術情報アクセスクラス", "１患者分の手術情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo) Then
				' 削除実行
				db.setSQL(sqlMTI_OPE.sqlDelOpe_Patient)	'DELETE文設定
				db.setParam(sqlMTI_OPE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setVal(sqlMTI_OPE.prmPATIENT_NO, pPatientNo)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の手術情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelOpeHsp(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "手術情報アクセスクラス", "１入退院分の手術情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo) Then
				' 削除実行
				db.setSQL(sqlMTI_OPE.sqlDelOpe_Hsp)	'DELETE文設定
				db.setParam(sqlMTI_OPE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setParam(sqlMTI_OPE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
				db.setVal(sqlMTI_OPE.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_OPE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の手術情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelOpeCh(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "手術情報アクセスクラス", "１科歴分の手術情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				' 削除実行
				db.setSQL(sqlMTI_OPE.sqlDelOpe_Ch)	'DELETE文設定
				db.setParam(sqlMTI_OPE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setParam(sqlMTI_OPE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
				db.setParam(sqlMTI_OPE.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
				db.setVal(sqlMTI_OPE.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_OPE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.setVal(sqlMTI_OPE.prmCH_NO, pChNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 手術情報１データを削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pOpeSerialNo">手術連番</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelOpeOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pOpeSerialNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "手術情報アクセスクラス", "手術情報１データを削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo, pChNo, pOpeSerialNo) Then
				' 削除実行
				db.setSQL(sqlMTI_OPE.sqlDelOpe_OneRec)	'DELETE文設定
				db.setParam(sqlMTI_OPE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setParam(sqlMTI_OPE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
				db.setParam(sqlMTI_OPE.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
				db.setParam(sqlMTI_OPE.prmOPE_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'手術連番
				db.setVal(sqlMTI_OPE.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_OPE.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.setVal(sqlMTI_OPE.prmCH_NO, pChNo, False)
				db.setVal(sqlMTI_OPE.prmOPE_SERIAL_NO, pOpeSerialNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 手術情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pOpeRec">手術情報クラス</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsOpeOneRec(ByVal db As clsDB, ByVal pOpeRec As datMTI_OPE_OneRec) As Integer
		Try
			Return execInsOpeOneRec(db, pOpeRec, True)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 手術情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pRow">手術情報 DataRow</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsOpeOneRec(ByVal db As clsDB, ByVal pRow As DataRow) As Integer
		Dim pOpeRec As datMTI_OPE_OneRec = Nothing
		Try
			Return execInsOpeOneRec(db, pRow, True)
		Catch ex As Exception
			Throw
		Finally
			pOpeRec = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 手術情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pRow">手術情報 DataRow</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsOpeOneRec(ByVal db As clsDB, ByVal pRow As DataRow, ByVal bLastUpdate As Boolean) As Integer
		Dim pOpeRec As datMTI_OPE_OneRec = Nothing
		Try
			pOpeRec = getOpeRecFromDataRow(pRow)
			Return execInsOpeOneRec(db, pOpeRec, bLastUpdate)
		Catch ex As Exception
			Throw
		Finally
			pOpeRec = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 手術情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pOpePlusRec">手術情報＋名称クラス</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsOpeOneRec(ByVal db As clsDB, ByVal pOpePlusRec As datMTI_OPE_PLUS_OneRec) As Integer
		Try
			Return execInsOpeOneRec(db, pOpePlusRec, True)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 手術情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pOpePlusRec">手術情報＋名称クラス</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsOpeOneRec(ByVal db As clsDB, ByVal pOpePlusRec As datMTI_OPE_PLUS_OneRec, ByVal bLastUpdate As Boolean) As Integer
		Dim pOpeRec As datMTI_OPE_OneRec = Nothing
		Try
			If pOpePlusRec IsNot Nothing Then
				pOpeRec = pOpePlusRec.OrgCopy
			End If
			Return execInsOpeOneRec(db, pOpeRec, bLastUpdate)
		Catch ex As Exception
			Throw
		Finally
			pOpeRec = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 手術情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pOpeRec">手術情報クラス</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsOpeOneRec(ByVal db As clsDB, ByVal pOpeRec As datMTI_OPE_OneRec, ByVal bLastUpdate As Boolean) As Integer
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "手術情報アクセスクラス", "手術情報１データを追加 Start")
		Try
			If pOpeRec Is Nothing Then
				Return 0
			End If
			' INSERT文設定
			db.setSQL(sqlMTI_OPE.sqlInsOpe_OneRec)
			' 患者番号
			db.setParam(sqlMTI_OPE.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmPATIENT_NO, pOpeRec.PATIENT_NO)
			' 入退院歴番号
			db.setParam(sqlMTI_OPE.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OPE.prmHSP_HISTORY_NO, pOpeRec.HSP_HISTORY_NO, False)
			' 科歴番号
			db.setParam(sqlMTI_OPE.prmCH_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OPE.prmCH_NO, pOpeRec.CH_NO, False)
			' 手術連番
			db.setParam(sqlMTI_OPE.prmOPE_SERIAL_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OPE.prmOPE_SERIAL_NO, pOpeRec.OPE_SERIAL_NO, False)
			' 手術区分コード
			db.setParam(sqlMTI_OPE.prmOPE_DIV, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmOPE_DIV, pOpeRec.OPE_DIV)
			' 手術名
			db.setParam(sqlMTI_OPE.prmOPE_NM, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmOPE_NM, pOpeRec.OPE_NM)
			' 実施日
			db.setParam(sqlMTI_OPE.prmOPE_DT, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_OPE.prmOPE_DT, pOpeRec.OPE_DT)
			' 実施時刻
			db.setParam(sqlMTI_OPE.prmOPE_TIME, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmOPE_TIME, pOpeRec.OPE_TIME)
			' 手術所要時間
			db.setParam(sqlMTI_OPE.prmOPE_REQUIRED_TIME, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmOPE_REQUIRED_TIME, pOpeRec.OPE_REQUIRED_TIME)
			' 手術時年齢
			db.setParam(sqlMTI_OPE.prmOPE_AGE, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OPE.prmOPE_AGE, pOpeRec.OPE_AGE, False)
			' 手術時月齢
			db.setParam(sqlMTI_OPE.prmOPE_MONTH_AGE, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OPE.prmOPE_MONTH_AGE, pOpeRec.OPE_MONTH_AGE, False)
			' 手術時日齢
			db.setParam(sqlMTI_OPE.prmOPE_DAY_AGE, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OPE.prmOPE_DAY_AGE, pOpeRec.OPE_DAY_AGE, False)
			' 麻酔区分コード１
			db.setParam(sqlMTI_OPE.prmANESTHESIA_DIV1, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmANESTHESIA_DIV1, pOpeRec.ANESTHESIA_DIV1)
			' 全身麻酔時間
			db.setParam(sqlMTI_OPE.prmANESTHESIA_TIME, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmANESTHESIA_TIME, pOpeRec.ANESTHESIA_TIME)
			' 麻酔区分コード２
			db.setParam(sqlMTI_OPE.prmANESTHESIA_DIV2, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmANESTHESIA_DIV2, pOpeRec.ANESTHESIA_DIV2)
			' 補助区分コード１
			db.setParam(sqlMTI_OPE.prmASST_DIV1, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmASST_DIV1, pOpeRec.ASST_DIV1)
			' 補助区分コード２
			db.setParam(sqlMTI_OPE.prmASST_DIV2, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmASST_DIV2, pOpeRec.ASST_DIV2)
			' 備考１
			db.setParam(sqlMTI_OPE.prmREMARKS1, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmREMARKS1, pOpeRec.REMARKS1)
			' 備考２
			db.setParam(sqlMTI_OPE.prmREMARKS2, clsDB.Enum_dbType.dbNumeric)
			If pOpeRec.REMARKS2.HasValue Then
				db.setVal(sqlMTI_OPE.prmREMARKS2, pOpeRec.REMARKS2.Value, False)
			Else
				db.setVal(sqlMTI_OPE.prmREMARKS2, 0)
			End If
			' 対応病名連番
			db.setParam(sqlMTI_OPE.prmSPT_DISEASE_SERIAL_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OPE.prmSPT_DISEASE_SERIAL_NO, pOpeRec.SPT_DISEASE_SERIAL_NO, False)
			' ＩＣＤ９ＣＭコード
			db.setParam(sqlMTI_OPE.prmICD9CM_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmICD9CM_CD, pOpeRec.ICD9CM_CD)
			' 大分類コード
			db.setParam(sqlMTI_OPE.prmL_GRP_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmL_GRP_CD, pOpeRec.L_GRP_CD)
			' 中分類コード
			db.setParam(sqlMTI_OPE.prmM_GRP_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmM_GRP_CD, pOpeRec.M_GRP_CD)
			' ３桁分類コード
			db.setParam(sqlMTI_OPE.prmDIGS3_GRP_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmDIGS3_GRP_CD, pOpeRec.DIGS3_GRP_CD)
			' 管理記号
			db.setParam(sqlMTI_OPE.prmMNG_DIV, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmMNG_DIV, pOpeRec.MNG_DIV)
			' 管理番号
			db.setParam(sqlMTI_OPE.prmMNG_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OPE.prmMNG_NO, pOpeRec.MNG_NO, False)
			' 手術回数コード
			db.setParam(sqlMTI_OPE.prmOPE_COUNT_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmOPE_COUNT_CD, pOpeRec.OPE_COUNT_CD)
			' 手術側数コード
			db.setParam(sqlMTI_OPE.prmOPE_PART_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmOPE_PART_CD, pOpeRec.OPE_PART_CD)
			' 終了日
			db.setParam(sqlMTI_OPE.prmEND_DT, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_OPE.prmEND_DT, pOpeRec.END_DT)
			' 終了時刻
			db.setParam(sqlMTI_OPE.prmEND_TIME, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmEND_TIME, pOpeRec.END_TIME)
			' 病名
			db.setParam(sqlMTI_OPE.prmSPT_DISEASE_NM, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmSPT_DISEASE_NM, pOpeRec.SPT_DISEASE_NM)
			' ＩＣＤ１０コード
			db.setParam(sqlMTI_OPE.prmSPT_DISEASE_ICD10_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmSPT_DISEASE_ICD10_CD, pOpeRec.SPT_DISEASE_ICD10_CD)
			' 病名転帰コード
			db.setParam(sqlMTI_OPE.prmSPT_DISEASE_OUTCOME_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmSPT_DISEASE_OUTCOME_CD, pOpeRec.SPT_DISEASE_OUTCOME_CD)
			' 病名管理記号
			db.setParam(sqlMTI_OPE.prmSPT_DISEASE_MNG_DIV1, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmSPT_DISEASE_MNG_DIV1, pOpeRec.SPT_DISEASE_MNG_DIV1)
			' 病名管理番号
			db.setParam(sqlMTI_OPE.prmSPT_DISEASE_MNG_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OPE.prmSPT_DISEASE_MNG_NO, pOpeRec.SPT_DISEASE_MNG_NO, False)
			' 点数表コード
			db.setParam(sqlMTI_OPE.prmSCORE_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmSCORE_CD, pOpeRec.SCORE_CD)
			' 術後日数
			db.setParam(sqlMTI_OPE.prmAFTER_OPE_DAYS, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OPE.prmAFTER_OPE_DAYS, pOpeRec.AFTER_OPE_DAYS, False)
			' 術後合併症有無コード
			db.setParam(sqlMTI_OPE.prmAFTER_OPE_CMPC_CHK, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmAFTER_OPE_CMPC_CHK, pOpeRec.AFTER_OPE_CMPC_CHK)
			' 院内手術コード
			db.setParam(sqlMTI_OPE.prmHSP_OPE_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmHSP_OPE_CD, pOpeRec.HSP_OPE_CD)
			' 術前日数
			db.setParam(sqlMTI_OPE.prmPRE_OPE_DAYS, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OPE.prmPRE_OPE_DAYS, pOpeRec.PRE_OPE_DAYS, False)
			' 緊急区分コード
			db.setParam(sqlMTI_OPE.prmPLAN_EMERGENCY_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmPLAN_EMERGENCY_CD, pOpeRec.PLAN_EMERGENCY_CD)
			' ＡＳＡ＿ＰＳコード
			db.setParam(sqlMTI_OPE.prmASA_PS_GRP_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OPE.prmASA_PS_GRP_CD, pOpeRec.ASA_PS_GRP_CD)
			' 時間外フラグ
			db.setParam(sqlMTI_OPE.prmTIME_OUT_FLG, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OPE.prmTIME_OUT_FLG, pOpeRec.TIME_OUT_FLG, False)
			' 出血量
			db.setParam(sqlMTI_OPE.prmBLEEDING_VOLUME, clsDB.Enum_dbType.dbInt)
			If pOpeRec.BLEEDING_VOLUME.HasValue Then
				db.setVal(sqlMTI_OPE.prmBLEEDING_VOLUME, pOpeRec.BLEEDING_VOLUME.Value, False)
			Else
				db.setVal(sqlMTI_OPE.prmBLEEDING_VOLUME, 0)
			End If
			' 輸血量
			db.setParam(sqlMTI_OPE.prmBLOOD_TRAN_VOLUME, clsDB.Enum_dbType.dbInt)
			If pOpeRec.BLOOD_TRAN_VOLUME.HasValue Then
				db.setVal(sqlMTI_OPE.prmBLOOD_TRAN_VOLUME, pOpeRec.BLOOD_TRAN_VOLUME.Value, False)
			Else
				db.setVal(sqlMTI_OPE.prmBLOOD_TRAN_VOLUME, 0)
			End If
			' データ取込日
			db.setParam(sqlMTI_OPE.prmDATA_CAPTURE_DT, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_OPE.prmDATA_CAPTURE_DT, pOpeRec.DATA_CAPTURE_DT)
			' 新規登録日
			db.setParam(sqlMTI_OPE.prmNEW_REG_DT, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_OPE.prmNEW_REG_DT, pOpeRec.NEW_REG_DT)
			' 更新者コード
			db.setParam(sqlMTI_OPE.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)
			If bLastUpdate OrElse String.IsNullOrEmpty(pOpeRec.LASTUPDUSER_CD) Then
				' 更新者コード←ログインＩＤ
				db.setVal(sqlMTI_OPE.prmLASTUPDUSER_CD, clsSysMst.getLoginId)
			Else
				db.setVal(sqlMTI_OPE.prmLASTUPDUSER_CD, pOpeRec.LASTUPDUSER_CD)
			End If
			' 最終更新日
			db.setParam(sqlMTI_OPE.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)
			If bLastUpdate OrElse pOpeRec.LASTUPD_DT.Equals(Nothing) Then
				' 最終更新日←システム日付
				db.setVal(sqlMTI_OPE.prmLASTUPD_DT, Now())
			Else
				db.setVal(sqlMTI_OPE.prmLASTUPD_DT, pOpeRec.LASTUPD_DT)
			End If
			' 追加実行
			Return db.execNonQuery(False)
		Catch ex As Exception
			Throw
		End Try
	End Function
End Class
