﻿Imports XCM
Imports System.Reflection

''' ---------------------------------------------
''' <summary>
''' 対診科情報アクセスクラス
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public NotInheritable Class clsMTI_OTHER_DEPT
	Implements IDisposable

#Region "解放処理"

	'解放処理時使用＊＊
	Protected disposed As Boolean = False

	''' ---------------------------------------------	
	''' <summary>
	''' Dispose（解放処理）※外からはよばない
	''' </summary>
	''' <param name="disposing"></param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overloads Sub Dispose(ByVal disposing As Boolean)
		If Not Me.disposed Then
		End If
		Me.disposed = True
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）
	''' </summary>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overloads Sub Dispose() Implements IDisposable.Dispose
		Dispose(True)
		GC.SuppressFinalize(Me)
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）※外からはよばない
	''' </summary>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overrides Sub Finalize()
		Dispose(False)
		MyBase.Finalize()
	End Sub
#End Region

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' </summary>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Sub New()
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String) As Boolean
		Try
			Return Not String.IsNullOrWhiteSpace(pPatientNo)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo) AndAlso (pHspHistoryNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo, pHspHistoryNo) AndAlso (pChNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 対診科情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>対診科情報クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOtherDeptOneRec(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As datMTI_OTHER_DEPT_OneRec
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOtherDeptOneRec(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 対診科情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>対診科情報クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOtherDeptOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As datMTI_OTHER_DEPT_OneRec
		Dim retDat As datMTI_OTHER_DEPT_OneRec = Nothing
		Dim arData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_OTHER_DEPT.sqlSelOtherDept_OneRec)	'SELECT文設定
			db.setParam(sqlMTI_OTHER_DEPT.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParam(sqlMTI_OTHER_DEPT.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParam(sqlMTI_OTHER_DEPT.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setVal(sqlMTI_OTHER_DEPT.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_OTHER_DEPT.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_OTHER_DEPT.prmCH_NO, pChNo, False)
			iRet = db.execQuery(GetType(datMTI_OTHER_DEPT_OneRec), arData)	'値取得
			If iRet > 0 Then									   'レコードあり
				retDat = DirectCast(arData(0), datMTI_OTHER_DEPT_OneRec)
			Else
				retDat = Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 対診科情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>対診科情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOtherDeptOneRecDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getOtherDeptOneRecDa(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 対診科情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>対診科情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getOtherDeptOneRecDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_OTHER_DEPT.sqlSelOtherDept_OneRec)

			db.setParamDa(sqlMTI_OTHER_DEPT.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParamDa(sqlMTI_OTHER_DEPT.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParamDa(sqlMTI_OTHER_DEPT.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
			db.setValDa(sqlMTI_OTHER_DEPT.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_OTHER_DEPT.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_OTHER_DEPT.prmCH_NO, pChNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の対診科情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelOtherDeptPatient(ByVal db As clsDB, ByVal pPatientNo As String)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "対診科情報アクセスクラス", "１患者分の対診科情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo) Then
				' 削除実行
				db.setSQL(sqlMTI_OTHER_DEPT.sqlDelOtherDept_Patient)	'DELETE文設定
				db.setParam(sqlMTI_OTHER_DEPT.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setVal(sqlMTI_OTHER_DEPT.prmPATIENT_NO, pPatientNo)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の対診科情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelOtherDeptHsp(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "対診科情報アクセスクラス", "１入退院分の対診科情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo) Then
				' 削除実行
				db.setSQL(sqlMTI_OTHER_DEPT.sqlDelOtherDept_Hsp)	'DELETE文設定
				db.setParam(sqlMTI_OTHER_DEPT.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setParam(sqlMTI_OTHER_DEPT.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
				db.setVal(sqlMTI_OTHER_DEPT.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_OTHER_DEPT.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 対診科情報１データを削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelOtherDeptOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "対診科情報アクセスクラス", "対診科情報１データを削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				' 削除実行
				db.setSQL(sqlMTI_OTHER_DEPT.sqlDelOtherDept_OneRec)	'DELETE文設定
				db.setParam(sqlMTI_OTHER_DEPT.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setParam(sqlMTI_OTHER_DEPT.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
				db.setParam(sqlMTI_OTHER_DEPT.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
				db.setVal(sqlMTI_OTHER_DEPT.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_OTHER_DEPT.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.setVal(sqlMTI_OTHER_DEPT.prmCH_NO, pChNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 対診科情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pOtherDeptRec">対診科情報クラス</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsOtherDeptOneRec(ByVal db As clsDB, ByVal pOtherDeptRec As datMTI_OTHER_DEPT_OneRec) As Integer
		Try
			Return execInsOtherDeptOneRec(db, pOtherDeptRec, True)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 対診科情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pOtherDeptRec">対診科情報クラス</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsOtherDeptOneRec(ByVal db As clsDB, ByVal pOtherDeptRec As datMTI_OTHER_DEPT_OneRec, ByVal bLastUpdate As Boolean) As Integer
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "対診科情報アクセスクラス", "対診科情報１データを追加 Start")
		Try
			If pOtherDeptRec Is Nothing Then
				Return 0
			End If
			' INSERT文設定
			db.setSQL(sqlMTI_OTHER_DEPT.sqlInsOtherDept_OneRec)
			' 患者番号
			db.setParam(sqlMTI_OTHER_DEPT.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_OTHER_DEPT.prmPATIENT_NO, pOtherDeptRec.PATIENT_NO)
			' 入退院歴番号
			db.setParam(sqlMTI_OTHER_DEPT.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmHSP_HISTORY_NO, pOtherDeptRec.HSP_HISTORY_NO, False)
			' 科歴番号
			db.setParam(sqlMTI_OTHER_DEPT.prmCH_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmCH_NO, pOtherDeptRec.CH_NO, False)
			' 対診科０１
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT01, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT01, pOtherDeptRec.OTHER_DEPT01, False)
			' 対診科０２
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT02, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT02, pOtherDeptRec.OTHER_DEPT02, False)
			' 対診科０３
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT03, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT03, pOtherDeptRec.OTHER_DEPT03, False)
			' 対診科０４
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT04, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT04, pOtherDeptRec.OTHER_DEPT04, False)
			' 対診科０５
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT05, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT05, pOtherDeptRec.OTHER_DEPT05, False)
			' 対診科０６
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT06, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT06, pOtherDeptRec.OTHER_DEPT06, False)
			' 対診科０７
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT07, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT07, pOtherDeptRec.OTHER_DEPT07, False)
			' 対診科０８
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT08, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT08, pOtherDeptRec.OTHER_DEPT08, False)
			' 対診科０９
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT09, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT09, pOtherDeptRec.OTHER_DEPT09, False)
			' 対診科１０
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT10, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT10, pOtherDeptRec.OTHER_DEPT10, False)
			' 対診科１１
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT11, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT11, pOtherDeptRec.OTHER_DEPT11, False)
			' 対診科１２
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT12, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT12, pOtherDeptRec.OTHER_DEPT12, False)
			' 対診科１３
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT13, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT13, pOtherDeptRec.OTHER_DEPT13, False)
			' 対診科１４
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT14, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT14, pOtherDeptRec.OTHER_DEPT14, False)
			' 対診科１５
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT15, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT15, pOtherDeptRec.OTHER_DEPT15, False)
			' 対診科１６
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT16, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT16, pOtherDeptRec.OTHER_DEPT16, False)
			' 対診科１７
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT17, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT17, pOtherDeptRec.OTHER_DEPT17, False)
			' 対診科１８
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT18, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT18, pOtherDeptRec.OTHER_DEPT18, False)
			' 対診科１９
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT19, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT19, pOtherDeptRec.OTHER_DEPT19, False)
			' 対診科２０
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT20, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT20, pOtherDeptRec.OTHER_DEPT20, False)
			' 対診科２１
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT21, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT21, pOtherDeptRec.OTHER_DEPT21, False)
			' 対診科２２
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT22, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT22, pOtherDeptRec.OTHER_DEPT22, False)
			' 対診科２３
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT23, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT23, pOtherDeptRec.OTHER_DEPT23, False)
			' 対診科２４
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT24, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT24, pOtherDeptRec.OTHER_DEPT24, False)
			' 対診科２５
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT25, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT25, pOtherDeptRec.OTHER_DEPT25, False)
			' 対診科２６
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT26, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT26, pOtherDeptRec.OTHER_DEPT26, False)
			' 対診科２７
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT27, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT27, pOtherDeptRec.OTHER_DEPT27, False)
			' 対診科２８
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT28, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT28, pOtherDeptRec.OTHER_DEPT28, False)
			' 対診科２９
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT29, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT29, pOtherDeptRec.OTHER_DEPT29, False)
			' 対診科３０
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT30, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT30, pOtherDeptRec.OTHER_DEPT30, False)
			' 対診科３１
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT31, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT31, pOtherDeptRec.OTHER_DEPT31, False)
			' 対診科３２
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT32, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT32, pOtherDeptRec.OTHER_DEPT32, False)
			' 対診科３３
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT33, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT33, pOtherDeptRec.OTHER_DEPT33, False)
			' 対診科３４
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT34, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT34, pOtherDeptRec.OTHER_DEPT34, False)
			' 対診科３５
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT35, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT35, pOtherDeptRec.OTHER_DEPT35, False)
			' 対診科３６
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT36, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT36, pOtherDeptRec.OTHER_DEPT36, False)
			' 対診科３７
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT37, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT37, pOtherDeptRec.OTHER_DEPT37, False)
			' 対診科３８
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT38, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT38, pOtherDeptRec.OTHER_DEPT38, False)
			' 対診科３９
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT39, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT39, pOtherDeptRec.OTHER_DEPT39, False)
			' 対診科４０
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT40, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT40, pOtherDeptRec.OTHER_DEPT40, False)
			' 対診科４１
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT41, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT41, pOtherDeptRec.OTHER_DEPT41, False)
			' 対診科４２
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT42, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT42, pOtherDeptRec.OTHER_DEPT42, False)
			' 対診科４３
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT43, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT43, pOtherDeptRec.OTHER_DEPT43, False)
			' 対診科４４
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT44, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT44, pOtherDeptRec.OTHER_DEPT44, False)
			' 対診科４５
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT45, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT45, pOtherDeptRec.OTHER_DEPT45, False)
			' 対診科４６
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT46, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT46, pOtherDeptRec.OTHER_DEPT46, False)
			' 対診科４７
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT47, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT47, pOtherDeptRec.OTHER_DEPT47, False)
			' 対診科４８
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT48, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT48, pOtherDeptRec.OTHER_DEPT48, False)
			' 対診科４９
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT49, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT49, pOtherDeptRec.OTHER_DEPT49, False)
			' 対診科５０
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT50, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT50, pOtherDeptRec.OTHER_DEPT50, False)
			' 対診科５１
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT51, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT51, pOtherDeptRec.OTHER_DEPT51, False)
			' 対診科５２
			db.setParam(sqlMTI_OTHER_DEPT.prmOTHER_DEPT52, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_OTHER_DEPT.prmOTHER_DEPT52, pOtherDeptRec.OTHER_DEPT52, False)
			' 更新者コード
			db.setParam(sqlMTI_OTHER_DEPT.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)
			If bLastUpdate OrElse String.IsNullOrEmpty(pOtherDeptRec.LASTUPDUSER_CD) Then
				' 更新者コード←ログインＩＤ
				db.setVal(sqlMTI_OTHER_DEPT.prmLASTUPDUSER_CD, clsSysMst.getLoginId)
			Else
				db.setVal(sqlMTI_OTHER_DEPT.prmLASTUPDUSER_CD, pOtherDeptRec.LASTUPDUSER_CD)
			End If
			' 最終更新日
			db.setParam(sqlMTI_OTHER_DEPT.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)
			If bLastUpdate OrElse pOtherDeptRec.LASTUPD_DT.Equals(Nothing) Then
				' 最終更新日←システム日付
				db.setVal(sqlMTI_OTHER_DEPT.prmLASTUPD_DT, Now())
			Else
				db.setVal(sqlMTI_OTHER_DEPT.prmLASTUPD_DT, pOtherDeptRec.LASTUPD_DT)
			End If
			' 追加実行
			Return db.execNonQuery(False)
		Catch ex As Exception
			Throw
		End Try
	End Function
End Class
